@@ -1,4 +1,4 @@
-//$Id: add-resource.cc,v 1.28 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: add-resource.cc,v 1.29 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -47,7 +47,7 @@ GUI::AddResourceWin::AddResourceWin (ResourceManager *manager_):
 
 #define ADD_TYPE(desc,t)                                                \
 	menu->items ().push_back (Gtk::Menu_Helpers::MenuElem (desc,			\
-		SigC::bind (SigC::slot (*this, &AddResourceWin::resource_type_cb),	\
+		sigc::bind (sigc::mem_fun (*this, &AddResourceWin::resource_type_cb),	\
 			    Resources::RESOURCE_##t)))
     
     ADD_TYPE(_("Form"),           FORM);
