@@ -1,4 +1,4 @@
-//$Id: add-resource.h,v 1.11 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: add-resource.h,v 1.12 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -31,7 +31,7 @@ namespace Guikachu
 {
     namespace GUI
     {
-	class AddResourceWin: public SigC::Object
+	class AddResourceWin: public sigc::trackable
 	{
 	    Glib::RefPtr<Gnome::Glade::Xml> gui;
 
