@@ -1,4 +1,4 @@
-//$Id: bitmapfamily-win.cc,v 1.5 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: bitmapfamily-win.cc,v 1.6 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -22,7 +22,7 @@
 #include "config.h"
 #include <libgnome/libgnome.h>
 
-#include <sigc++/bind_return.h>
+#include <sigc++/adaptors/bind_return.h>
 
 #include "io/io.h"
 
@@ -52,7 +52,7 @@
 using namespace Guikachu;
 
 namespace {
-    class ImageFileSelector: public SigC::Object
+    class ImageFileSelector: public sigc::trackable
     {
         Gtk::FileSelection             fs;
         Resources::BitmapFamily       *res;
@@ -75,14 +75,11 @@ GUI::BitmapFamilyWindow::BitmapFamilyWindow (Resources::BitmapFamily *res_):
     res (res_),
     type (Resources::Bitmap::TYPE_COLOR_256)
 {
-    using namespace SigC;
     using ResourceOps::PropChangeOpFactory;
     using ResourceOps::RenameOpFactory;
     
     window.signal_delete_event ().connect (
-	SigC::bind_return (
-	    SigC::hide<GdkEventAny*> (SigC::slot (window, &Gtk::Widget::hide)),
-	    true));
+	sigc::bind_return (sigc::hide (sigc::mem_fun (window, &Gtk::Widget::hide)), true));
     window.property_allow_grow () = true;
 
     Gtk::VBox *main_vbox = new Gtk::VBox (false, 5);
@@ -101,15 +98,15 @@ GUI::BitmapFamilyWindow::BitmapFamilyWindow (Resources::BitmapFamily *res_):
     Gtk::Box *buttonbox = new Gtk::HBox (false, 5);
     main_vbox->pack_end (*manage (buttonbox), false, false);
     load_button = UI::create_stock_button (Gtk::Stock::OPEN, _("Load"));
-    load_button->signal_clicked ().connect (SigC::slot (*this, &BitmapFamilyWindow::load_cb));
+    load_button->signal_clicked ().connect (sigc::mem_fun (*this, &BitmapFamilyWindow::load_cb));
     buttonbox->add (*manage (load_button));
 
     export_button = UI::create_stock_button (Gtk::Stock::SAVE_AS, _("Export"));
-    export_button->signal_clicked ().connect (SigC::slot (*this, &BitmapFamilyWindow::export_cb));
+    export_button->signal_clicked ().connect (sigc::mem_fun (*this, &BitmapFamilyWindow::export_cb));
     buttonbox->add (*manage (export_button));
 
     remove_button = UI::create_stock_button (Gtk::Stock::REMOVE, _("Remove"));
-    remove_button->signal_clicked ().connect (SigC::slot (*this, &BitmapFamilyWindow::remove_cb));
+    remove_button->signal_clicked ().connect (sigc::mem_fun (*this, &BitmapFamilyWindow::remove_cb));
     buttonbox->add (*manage (remove_button));
 
     /* List of color depths */
@@ -118,7 +115,7 @@ GUI::BitmapFamilyWindow::BitmapFamilyWindow (Resources::BitmapFamily *res_):
     scroll_win->set_policy (Gtk::POLICY_NEVER, Gtk::POLICY_NEVER);
     DepthList *depth_list = new DepthList (res);
     scroll_win->add (*manage (depth_list));
-    depth_list->type_changed.connect (SigC::slot (*this, &BitmapFamilyWindow::type_changed_cb));
+    depth_list->type_changed.connect (sigc::mem_fun (*this, &BitmapFamilyWindow::type_changed_cb));
 
     /* Preview */
     Gtk::Alignment *align = new Gtk::Alignment (0.5, 0.5, 0, 0);
@@ -133,7 +130,7 @@ GUI::BitmapFamilyWindow::BitmapFamilyWindow (Resources::BitmapFamily *res_):
     
     window.add (*manage (main_vbox));
 
-    res->changed.connect (slot (*this, &BitmapFamilyWindow::update));
+    res->changed.connect (sigc::mem_fun (*this, &BitmapFamilyWindow::update));
     update ();
 }
 
@@ -242,22 +239,20 @@ ImageFileSelector::ImageFileSelector (Gtk::Window                   &parent,
 	title = g_strdup_printf (_("Exporting %s"), res->id ().c_str ());
 	fs.show_fileop_buttons ();
 	fs.get_ok_button ()->signal_clicked ().connect (
-	    SigC::slot (*this, &ImageFileSelector::export_cb));
+	    sigc::mem_fun (*this, &ImageFileSelector::export_cb));
     } else {
 	title = g_strdup_printf (_("Loading image file to %s"), res->id ().c_str ());
 	fs.hide_fileop_buttons ();
 	fs.get_ok_button ()->signal_clicked ().connect (
-	    SigC::slot (*this, &ImageFileSelector::open_cb));
+	    sigc::mem_fun (*this, &ImageFileSelector::open_cb));
     }
     fs.set_title (title);
     g_free (title);
     
     fs.get_cancel_button ()->signal_clicked ().connect (
-	SigC::slot (*this, &ImageFileSelector::close_cb));
+	sigc::mem_fun (*this, &ImageFileSelector::close_cb));
     fs.signal_delete_event ().connect (
-	SigC::bind_return (
-	    SigC::hide<GdkEventAny*> (SigC::slot (*this, &ImageFileSelector::close_cb)),
-	    true));
+	sigc::bind_return (sigc::hide (sigc::mem_fun (*this, &ImageFileSelector::close_cb)), true));
     
     fs.set_transient_for (parent);
     fs.set_modal (true);
