@@ -1,4 +1,4 @@
-//$Id: blob-win.cc,v 1.10 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: blob-win.cc,v 1.11 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -32,12 +32,10 @@ GUI::BlobWindow::BlobWindow (Guikachu::Resources::Blob *res_):
     res (res_),
     window (Gtk::WINDOW_TOPLEVEL)
 {
-    using namespace SigC;
-
     using ResourceOps::RenameOpFactory;
     using ResourceOps::PropChangeOpFactory;
     
-    window.signal_delete_event ().connect (slot (*this, &BlobWindow::delete_event_impl));
+    window.signal_delete_event ().connect (sigc::mem_fun (*this, &BlobWindow::delete_event_impl));
     window.property_allow_grow () = true;
 
     GUI::PropertyTable *proptable = new GUI::PropertyTable ();
@@ -56,7 +54,7 @@ GUI::BlobWindow::BlobWindow (Guikachu::Resources::Blob *res_):
     
     window.add (*manage (proptable));
     
-    res->changed.connect (slot (*this, &BlobWindow::update));
+    res->changed.connect (sigc::mem_fun (*this, &BlobWindow::update));
     update ();
 }
 
