@@ -1,4 +1,4 @@
-//$Id: depthlist.cc,v 1.3 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: depthlist.cc,v 1.4 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -47,9 +47,9 @@ DepthList::DepthList (Resources::BitmapFamily *res_):
 
     get_selection ()->set_mode (Gtk::SELECTION_BROWSE);
     get_selection ()->signal_changed ().connect (
-	SigC::slot (*this, &DepthList::selection_changed_cb));
+	sigc::mem_fun (*this, &DepthList::selection_changed_cb));
     
-    res->changed.connect (SigC::slot (*this, &DepthList::update));
+    res->changed.connect (sigc::mem_fun (*this, &DepthList::update));
 
     const depth_list_t &depth_list = get_depth_list ();
     for (depth_list_t::const_iterator i = depth_list.begin ();
