@@ -1,4 +1,4 @@
-//$Id: depthlist.h,v 1.3 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: depthlist.h,v 1.4 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -39,7 +39,7 @@ namespace Guikachu
 	    
         public:
             DepthList (Resources::BitmapFamily *res);
-            SigC::Signal1<void, Resources::Bitmap::BitmapType> type_changed;
+            sigc::signal1<void, Resources::Bitmap::BitmapType> type_changed;
             
         private:
 	    bool update_block;
