@@ -1,4 +1,4 @@
-//$Id: dialog-win-helpers.cc,v 1.4 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: dialog-win-helpers.cc,v 1.5 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -38,7 +38,7 @@ ButtonList::ButtonList (Resources::Dialog *res_):
 {
     // Create "Default" button
     Gtk::Button *button_default = new Gtk::Button;
-    button_default->signal_clicked ().connect (SigC::slot (*this, &ButtonList::button_default_cb));
+    button_default->signal_clicked ().connect (sigc::mem_fun (*this, &ButtonList::button_default_cb));
     
     Gtk::Box *box = new Gtk::HBox;
     box->add (*manage (new Gtk::Image (
