@@ -1,4 +1,4 @@
-//$Id: dialog-win.cc,v 1.37 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: dialog-win.cc,v 1.38 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -23,7 +23,7 @@
 
 #include <gtkmm/menu.h>
 #include <gtkmm/notebook.h>
-#include <sigc++/bind_return.h>
+#include <sigc++/adaptors/bind_return.h>
 
 #include "property-ops-resource.h"
 
@@ -39,13 +39,12 @@ GUI::DialogWindow::DialogWindow (Resources::Dialog *res_):
     res (res_),
     update_block (true)
 {
-    using namespace SigC;
     using ResourceOps::PropChangeOpFactory;
     using ResourceOps::RenameOpFactory;
     using ResourceOps::StringListOpFactory;
     using namespace DialogWin_Helpers;
     
-    window.signal_delete_event ().connect (slot (*this, &DialogWindow::delete_event_impl));
+    window.signal_delete_event ().connect (sigc::mem_fun (*this, &DialogWindow::delete_event_impl));
     window.property_allow_grow () = true;
     
     Gtk::Notebook *notebook = new Gtk::Notebook;
@@ -67,11 +66,11 @@ GUI::DialogWindow::DialogWindow (Resources::Dialog *res_):
     /* Type */
     Gtk::Menu *type_menu = new Gtk::Menu;
 
-#define DIALOG_TYPE(s,t)						\
-	    type_menu->items ().push_back (				\
-		Gtk::Menu_Helpers::MenuElem (				\
-		    s,							\
-		    bind (slot (*this, &DialogWindow::type_menu_cb),	\
+#define DIALOG_TYPE(s,t)								\
+	    type_menu->items ().push_back (						\
+		Gtk::Menu_Helpers::MenuElem (						\
+		    s,									\
+		    sigc::bind (sigc::mem_fun (*this, &DialogWindow::type_menu_cb), 	\
 			  Resources::Dialog::t)));
 
     DIALOG_TYPE (_("Information"),  TYPE_INFORMATION);
@@ -114,7 +113,7 @@ GUI::DialogWindow::DialogWindow (Resources::Dialog *res_):
 					
     window.add (*manage (notebook));
     
-    res->changed.connect (slot (*this, &DialogWindow::update));
+    res->changed.connect (sigc::mem_fun (*this, &DialogWindow::update));
     update ();
 }
 
