@@ -1,4 +1,4 @@
-//$Id: dialog-win.h,v 1.17 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: dialog-win.h,v 1.18 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -30,7 +30,7 @@ namespace Guikachu
     namespace GUI
     {
 	class DialogWindow: public ResourceWindow,
-			    public SigC::Object
+			    public sigc::trackable
 	{
 	    Resources::Dialog   *res;
 	    
