@@ -1,4 +1,4 @@
-//$Id: edit-cut-and-paste.cc,v 1.8 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: edit-cut-and-paste.cc,v 1.9 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -42,23 +42,27 @@ namespace
     const char *TARGET_RES    = "application/x-guikachu/resources";
     const char *TARGET_WIDGET = "application/x-guikachu/widgets";
     
-    inline GdkAtom get_resource_target () { return gdk_atom_intern (TARGET_RES, false);    }
-    inline GdkAtom get_widget_target ()   { return gdk_atom_intern (TARGET_WIDGET, false); }
-    inline GdkAtom get_clipboard ()       { return gdk_atom_intern ("CLIPBOARD", false);   }
-    
     struct
     {
-	GdkAtom           target;
+	std::string       target;
 	char             *buffer;
 	GnomeVFSFileSize  length;
 	
 	void reset () {
 	    xmlFree (buffer);
-	    target = 0;
+	    target = "";
 	    buffer = 0;
 	    length = 0;
 	}
-    } clipboard_contents = { 0, 0, 0 };
+
+        void set_data (Gtk::SelectionData &data) {
+            if (data.get_target () != target)
+                return;
+            
+            data.set (target, 8, (guchar*) buffer, length);
+        }
+        
+    } clipboard_contents = { "", 0, 0 };
     
     union
     {
@@ -66,13 +70,12 @@ namespace
 	Resources::Form *form;
     } clipboard_state;
     
-    void selection_received_cb (GtkSelectionData *data, guint format);
-    void selection_requested_cb (GtkSelectionData *data, guint format, guint sel_closure);
+    void selection_received_cb (const Gtk::SelectionData &data);
+    void selection_requested_cb (Gtk::SelectionData &data, guint info);
+    void selection_cleared_cb ();
     
-    void paste_resources_impl (GtkSelectionData *data);
-    void paste_widgets_impl   (GtkSelectionData *data);
-    
-    Gtk::Widget * clipboard_widget ();
+    void paste_resources_impl (const Gtk::SelectionData &data);
+    void paste_widgets_impl   (const Gtk::SelectionData &data);
     
 } // anonymous namespace
 
@@ -98,14 +101,15 @@ void Edit::copy_resource (Resource *resource)
     clipboard_contents.reset ();
     storage.save_buffer (clipboard_contents.buffer, clipboard_contents.length);
     
-    // Set auxillary window as selection's owner
-    GdkAtom target_atom = get_resource_target ();
-    GdkAtom selection = get_clipboard ();
-
-    clipboard_contents.target = target_atom;
+    // Set the selection
+    std::list<Gtk::TargetEntry> targets;
+    targets.push_back (Gtk::TargetEntry (TARGET_RES));
+    clipboard_contents.target = TARGET_RES;
     
-    gtk_selection_add_target (clipboard_widget ()->gobj (), selection, target_atom, 0);
-    gtk_selection_owner_set (clipboard_widget ()->gobj (), selection, GDK_CURRENT_TIME);
+    Glib::RefPtr<Gtk::Clipboard> clipboard = Gtk::Clipboard::get ();
+    clipboard->set (targets,
+                    sigc::ptr_fun (selection_requested_cb),
+                    sigc::ptr_fun (selection_cleared_cb));
 }
 
 void Edit::copy_widget (Widget *widget)
@@ -122,15 +126,17 @@ void Edit::copy_widget (Widget *widget)
     widget->apply_visitor (saver);
 
     clipboard_contents.reset ();
-    storage.save_buffer (clipboard_contents.buffer, clipboard_contents.length);
-    
-    GdkAtom target_atom = get_widget_target ();
-    GdkAtom selection = get_clipboard ();
+    storage.save_buffer (clipboard_contents.buffer, clipboard_contents.length);    
 
-    clipboard_contents.target = target_atom;
+    // Set the selection
+    std::list<Gtk::TargetEntry> targets;
+    targets.push_back (Gtk::TargetEntry (TARGET_WIDGET));
+    clipboard_contents.target = TARGET_WIDGET;
     
-    gtk_selection_add_target (clipboard_widget ()->gobj (), selection, target_atom, 0);
-    gtk_selection_owner_set (clipboard_widget ()->gobj (), selection, GDK_CURRENT_TIME);
+    Glib::RefPtr<Gtk::Clipboard> clipboard = Gtk::Clipboard::get ();
+    clipboard->set (targets,
+                    sigc::ptr_fun (selection_requested_cb),
+                    sigc::ptr_fun (selection_cleared_cb));
 }
 
 void Edit::copy_widgets (const std::set<Widget*> &widgets)
@@ -155,13 +161,15 @@ void Edit::copy_widgets (const std::set<Widget*> &widgets)
     clipboard_contents.reset ();
     storage.save_buffer (clipboard_contents.buffer, clipboard_contents.length);
     
-    GdkAtom target_atom = get_widget_target ();
-    GdkAtom selection = get_clipboard ();
-
-    clipboard_contents.target = target_atom;
+    // Set the selection
+    std::list<Gtk::TargetEntry> targets;
+    targets.push_back (Gtk::TargetEntry (TARGET_WIDGET));
+    clipboard_contents.target = TARGET_WIDGET;
     
-    gtk_selection_add_target (clipboard_widget ()->gobj (), selection, target_atom, 0);
-    gtk_selection_owner_set (clipboard_widget ()->gobj (), selection, GDK_CURRENT_TIME);
+    Glib::RefPtr<Gtk::Clipboard> clipboard = Gtk::Clipboard::get ();
+    clipboard->set (targets,
+                    sigc::ptr_fun (selection_requested_cb), 
+                    sigc::ptr_fun (selection_cleared_cb));
 }
 
 
@@ -169,12 +177,10 @@ void Edit::copy_widgets (const std::set<Widget*> &widgets)
 void Edit::paste_resources (ResourceManager *manager)
 {
     clipboard_state.manager = manager;
-
+    
     // Request selection
-    GdkAtom target_atom = get_resource_target ();
-    GdkAtom selection = get_clipboard ();
-
-    gtk_selection_convert (clipboard_widget ()->gobj (), selection, target_atom, GDK_CURRENT_TIME);
+    Glib::RefPtr<Gtk::Clipboard> clipboard = Gtk::Clipboard::get ();
+    clipboard->request_contents (TARGET_RES, sigc::ptr_fun (selection_received_cb));
 }
 
 void Edit::paste_widgets (Resources::Form *form)
@@ -182,63 +188,43 @@ void Edit::paste_widgets (Resources::Form *form)
     clipboard_state.form = form;
 
     // Request selection
-    GdkAtom target_atom = get_widget_target ();
-    GdkAtom selection = get_clipboard ();
-
-    gtk_selection_convert (clipboard_widget ()->gobj (), selection, target_atom, GDK_CURRENT_TIME);
+    Glib::RefPtr<Gtk::Clipboard> clipboard = Gtk::Clipboard::get ();
+    clipboard->request_contents (TARGET_WIDGET, sigc::ptr_fun (selection_received_cb));
 }
 
 
-
 namespace
 {
     
-Gtk::Widget * clipboard_widget ()
+void selection_requested_cb (Gtk::SelectionData &data, guint info)
 {
-    static Gtk::Widget *widget = 0;
-    
-    if (!widget)
-    {
-	widget = new Gtk::Invisible;
-	widget->signal_selection_received ().connect (SigC::slot (selection_received_cb));
-	widget->signal_selection_get ().connect (SigC::slot (selection_requested_cb));
-    }
-    
-    return widget;
-}
-    
-void selection_requested_cb (GtkSelectionData *data, guint format, guint sel_closure)
-{
-    if (data->target != clipboard_contents.target)
-    {
-	data->length = 0;
-	return;
-    }
-
-    gtk_selection_data_set (data, clipboard_contents.target, 8,
-			    (guchar*) clipboard_contents.buffer,
-			    clipboard_contents.length);
+    clipboard_contents.set_data (data);
 }
 
-void selection_received_cb (GtkSelectionData *data, guint format)
+void selection_received_cb (const Gtk::SelectionData &data)
 {
-    if (!data->length)
+    if (!data.get_length ())
 	return;
     
-    if (data->target == get_resource_target ())
+    if (data.get_target () == TARGET_RES)
 	paste_resources_impl (data);
-    else if (data->target == get_widget_target ())
+    else if (data.get_target () == TARGET_WIDGET)
 	paste_widgets_impl (data);
 }
 
-void paste_resources_impl (GtkSelectionData *data)
+void selection_cleared_cb ()
+{
+    // Do nothing
+}
+
+void paste_resources_impl (const Gtk::SelectionData &data)
 {
     // TODO: Check format and everything
     
     // Read XML from X selection and parse it
     xmlParserCtxtPtr parser_ctxt =
-	xmlCreatePushParserCtxt (0, 0, (char*)data->data, data->length, "");
-    xmlParseChunk (parser_ctxt, (char*)data->data, 0, 1);
+	xmlCreatePushParserCtxt (0, 0, (char*)data.get_data (), data.get_length (), "");
+    xmlParseChunk (parser_ctxt, (char*)data.get_data (), 0, 1);
     
     xmlDocPtr doc = parser_ctxt->myDoc;
     
@@ -291,14 +277,14 @@ void paste_resources_impl (GtkSelectionData *data)
     }
 }
 
-void paste_widgets_impl (GtkSelectionData *data)
+void paste_widgets_impl (const Gtk::SelectionData &data)
 {
     // TODO: Check format and everything
     
     // Read XML from X selection and parse it
     xmlParserCtxtPtr parser_ctxt =
-	xmlCreatePushParserCtxt (0, 0, (char*)data->data, data->length, "");
-    xmlParseChunk (parser_ctxt, (char*)data->data, 0, 1);
+	xmlCreatePushParserCtxt (0, 0, (char*)data.get_data (), data.get_length (), "");
+    xmlParseChunk (parser_ctxt, (char*)data.get_data (), 0, 1);
     
     xmlDocPtr doc = parser_ctxt->myDoc;
     
@@ -350,4 +336,4 @@ void paste_widgets_impl (GtkSelectionData *data)
     }
 }
 
-} // anonymous namespace
+} // Anonymous namespace
