@@ -1,4 +1,4 @@
-//$Id: auto-resizeable.cc,v 1.8 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: auto-resizeable.cc,v 1.9 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -28,8 +28,8 @@ AutoWidth::AutoWidth (VSignal &changed):
     manual_width (manual_width_changed, false),
     manual_sync_block (false)
 {
-    manual_width.changed.connect (SigC::slot (*this, &AutoWidth::manual_width_cb));
-    width.changed.connect (SigC::slot (*this, &AutoWidth::width_changed_cb));
+    manual_width.changed.connect (sigc::mem_fun (*this, &AutoWidth::manual_width_cb));
+    width.changed.connect (sigc::mem_fun (*this, &AutoWidth::width_changed_cb));
 }
 
 int AutoWidth::get_width () const
@@ -64,8 +64,8 @@ AutoHeight::AutoHeight (VSignal &changed):
     manual_height (manual_height_changed, false),
     manual_sync_block(false)
 {
-    manual_height.changed.connect (SigC::slot (*this, &AutoHeight::manual_height_cb));
-    height.changed.connect (SigC::slot (*this, &AutoHeight::height_changed_cb));
+    manual_height.changed.connect (sigc::mem_fun (*this, &AutoHeight::manual_height_cb));
+    height.changed.connect (sigc::mem_fun (*this, &AutoHeight::height_changed_cb));
 }
 
 int AutoHeight::get_height () const
