@@ -1,4 +1,4 @@
-//$Id: button-prop.cc,v 1.29 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: button-prop.cc,v 1.30 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -40,7 +40,6 @@ ButtonProperties::ButtonProperties (Button *res_):
     res (res_),
     update_block (false)
 {
-    using namespace SigC;
     using Gtk::manage;
     
     using WidgetOps::PropChangeOpFactory;
@@ -62,11 +61,11 @@ ButtonProperties::ButtonProperties (Button *res_):
     /* Fill the frame type dropdown list */
     Gtk::Menu *frame_menu = new Gtk::Menu;
 
-#define FRAME_TYPE(s,t) 						  \
-	    frame_menu->items ().push_back (				  \
-		Gtk::Menu_Helpers::MenuElem (				  \
-		    s,							  \
-		    bind (slot (*this, &ButtonProperties::frame_menu_cb), \
+#define FRAME_TYPE(s,t) 						  		\
+	    frame_menu->items ().push_back (				  		\
+		Gtk::Menu_Helpers::MenuElem (				  		\
+		    s,							  		\
+		    sigc::bind (sigc::mem_fun (*this, &ButtonProperties::frame_menu_cb),\
 			  Widgets::Button::t)));
 
     FRAME_TYPE (_("None"),   FRAME_NONE);
@@ -115,7 +114,7 @@ ButtonProperties::ButtonProperties (Button *res_):
     proptable->show ();
     property_editor = proptable;
 
-    res->changed.connect (slot (*this, &ButtonProperties::update));
+    res->changed.connect (sigc::mem_fun (*this, &ButtonProperties::update));
     update ();
 }
 
