@@ -1,4 +1,4 @@
-//$Id: button-prop.h,v 1.13 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: button-prop.h,v 1.14 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -22,7 +22,6 @@
 #include "button.h"
 #include "widget-prop.h"
 
-#include <sigc++/object.h>
 #include <gtkmm/optionmenu.h>
 
 namespace Guikachu
@@ -32,7 +31,7 @@ namespace Guikachu
 	namespace FormEditor
 	{
 	    class ButtonProperties: public WidgetProperties,
-				    public SigC::Object
+				    public sigc::trackable
 	    {
 		Widgets::Button   *res;
 		
