@@ -1,4 +1,4 @@
-//$Id: form-editor-canvas.cc,v 1.13 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: form-editor-canvas.cc,v 1.14 2004/06/12 17:55:49 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -81,6 +81,9 @@ FooCanvasmm::Item * FormEditor::draw_text (FooCanvasmm::Group &group,
     
     Glib::RefPtr<Gdk::Pixbuf> clipped_pixbuf =
         clip_pos_pixbuf (pixbuf, true, x, y, clip_width, clip_height, anchor);
+
+    if (!clipped_pixbuf)
+        return 0;
     
     int width = clipped_pixbuf->get_width ();
     int height = clipped_pixbuf->get_height ();
@@ -175,6 +178,9 @@ namespace
     if (clip_height)
         clip_size_y -= std::max (0, (y + height - (clip_y + clip_height)));
 
+    if (!(clip_size_x > 0 && clip_size_y > 0))
+        return Glib::RefPtr<Gdk::Pixbuf> (0);
+    
     Glib::RefPtr<Gdk::Pixbuf> dest = Gdk::Pixbuf::create (Gdk::COLORSPACE_RGB, true, 8, clip_size_x, clip_size_y);
 
     x += clip_offset_x;
@@ -480,6 +486,9 @@ FooCanvasmm::Item * FormEditor::draw_bitmap (FooCanvasmm::Group            &grou
     // Clip pixbuf to desired size
     pixbuf = clip_pos_pixbuf (pixbuf_img, false, x, y, clip_width, clip_height, anchor);
 
+    if (!pixbuf)
+        return 0;
+    
     // Create parent group to store background + pixbuf
     FooCanvasmm::Group *ret_val = new FooCanvasmm::Group (group, x, y);
 
