@@ -1,6 +1,6 @@
-//$Id: form-editor-canvas.h,v 1.9 2004/01/20 22:52:15 cactus Exp $ -*- c++ -*-
+//$Id: form-editor-canvas.h,v 1.11 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -19,9 +19,7 @@
 #ifndef GUIKACHU_FORM_EDITOR_CANVAS_H
 #define GUIKACHU_FORM_EDITOR_CANVAS_H
 
-#include <gnome--/canvas.h>
-#include <gtk/gtkpacker.h> /* For GtkAnchor */
-#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <foocanvasmm/canvas.h>
 
 #include "form-editor/font.h"
 #include "bitmap-res.h"
@@ -33,52 +31,50 @@ namespace Guikachu
     {
 	namespace FormEditor
 	{
-	    Gnome::CanvasItem * draw_text (Gnome::CanvasGroup &group,
+            FooCanvasmm::Item * draw_text (FooCanvasmm::Group &group,
                                            const std::string  &text,
                                            const Font         &font,
-                                           const Gdk_Color    &color,
+                                           const Gdk::Color   &color,
                                            int                 x,
                                            int                 y,
                                            int                 clip_width,
                                            int                 clip_height,
-                                           GtkAnchorType       anchor = GTK_ANCHOR_CENTER,
+                                           Gtk::AnchorType     anchor = Gtk::ANCHOR_CENTER,
                                            bool                multi_line = false);
-
-            GdkPixbuf * render_bitmap (const Magick::Image           &image,
-                                       Resources::Bitmap::BitmapType  bitmap_type);
-
+            
+            Glib::RefPtr<Gdk::Pixbuf> render_bitmap (const Magick::Image           &image,
+                                                     Resources::Bitmap::BitmapType  bitmap_type);
+            
 	    // Use this instead of Rectangle canvas items because
 	    // those are shoddy
-	    Gnome::CanvasItem * draw_rectangle (Gnome::CanvasGroup &group,
+	    FooCanvasmm::Item * draw_rectangle (FooCanvasmm::Group &group,
                                                 int x1, int y1,
                                                 int x2, int y2);
 	    
-	    Gnome::CanvasItem * draw_pixbuf (Gnome::CanvasGroup &group,
+	    FooCanvasmm::Item * draw_pixbuf (FooCanvasmm::Group &group,
                                              GdkPixbuf          *pixbuf,
                                              int                 x = 0,
                                              int                 y = 0);
             
-            Gnome::CanvasItem * draw_bitmap (Gnome::CanvasGroup            &group,
+            FooCanvasmm::Item * draw_bitmap (FooCanvasmm::Group            &group,
                                              const Magick::Image           &image,
                                              Resources::Bitmap::BitmapType  bitmap_type,
-                                             const std::string             &background_color,
+                                             const Gdk::Color              &background_color,
                                              int                            x,
                                              int                            y,
                                              int                            clip_width = 0,
                                              int                            clip_height = 0,
-                                             GtkAnchorType                  anchor = GTK_ANCHOR_NW);
+                                             Gtk::AnchorType                anchor = Gtk::ANCHOR_NW);
 
-            Gnome::CanvasItem * draw_bitmapref (Gnome::CanvasGroup            &group,
+            FooCanvasmm::Item * draw_bitmapref (FooCanvasmm::Group            &group,
                                                 const Properties::ResourceRef &ref_prop,
                                                 bool                           color,
-                                                const std::string             &background_color,
+                                                const Gdk::Color              &background_color,
                                                 int                            x,
                                                 int                            y,
                                                 int                            clip_width = 0,
                                                 int                            clip_height = 0,
-                                                GtkAnchorType                  anchor = GTK_ANCHOR_NW);
-                                                
-                                                
+                                                Gtk::AnchorType                anchor = Gtk::ANCHOR_NW);
 	}
     }
 }
