@@ -1,4 +1,4 @@
-//$Id: list-canvas.h,v 1.9 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: list-canvas.h,v 1.10 2004/06/12 16:33:38 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -33,13 +33,14 @@ namespace Guikachu
 	    class ListCanvasItem: public WidgetCanvasItem,
 				  public ResizeableCanvasItem
 	    {
-		Widgets::List      *widget;
-		FooCanvasmm::Group *group;
+		Widgets::List *widget;
+
 	    public:
 		ListCanvasItem (Widgets::List      *widget,
 				FooCanvasmm::Group &parent_group);
+
 	    protected:
-		virtual void update ();
+		virtual void draw (FooCanvasmm::Group &group) const;
 	    };
 	}
     }
