@@ -1,4 +1,4 @@
-//$Id: palette.h,v 1.10 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: palette.h,v 1.12 2004/06/27 11:06:11 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -49,13 +49,13 @@ namespace Guikachu
 	public:
 	    Palette ();
 
-	    SigC::Signal1<void, Widgets::Type> palette_changed;
+	    sigc::signal1<void, Widgets::Type> palette_changed;
 	    void palette_applied ();
 	    
 	private:
 	    Gtk::ToggleButton* create_button (Widgets::Type       type,
 					      const std::string  &tooltip,
-					      const char * const *icon_xpm);
+					      const char * const *icon_xpm = 0);
 
 	    int  delete_event_impl (GdkEventAny *e);
 
