@@ -1,4 +1,4 @@
-//$Id: scrollbar-prop.cc,v 1.18 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: scrollbar-prop.cc,v 1.19 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -36,7 +36,6 @@ ScrollBarProperties::ScrollBarProperties (ScrollBar *res_):
     WidgetProperties (res_),
     res (res_)
 {
-    using namespace SigC;
     using WidgetOps::PropChangeOpFactory;
     
     GUI::PropertyTable *proptable = new GUI::PropertyTable ();
@@ -109,7 +108,7 @@ ScrollBarProperties::ScrollBarProperties (ScrollBar *res_):
     proptable->show ();
     property_editor = proptable;
 
-    res->changed.connect (SigC::slot (*this, &ScrollBarProperties::update));
+    res->changed.connect (sigc::mem_fun (*this, &ScrollBarProperties::update));
 }
 
 ScrollBarProperties::~ScrollBarProperties ()
