@@ -1,4 +1,4 @@
-//$Id: selector-trigger-canvas.cc,v 1.33 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: selector-trigger-canvas.cc,v 1.36 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -31,20 +31,13 @@ SelectorTriggerCanvasItem::SelectorTriggerCanvasItem (Widgets::SelectorTrigger *
     CanvasItem (widget_, parent_group),
     WidgetCanvasItem (widget_, parent_group),
     ResizeableCanvasItem (widget_, parent_group, new WidgetOps::ResizeOpFactory (widget_)),
-    widget (widget_),
-    group (0)
+    widget (widget_)
 {
-    widget->bitmap_id.resource_changed.connect (SigC::slot (*this, &SelectorTriggerCanvasItem::update));
-    update ();
+    widget->bitmap_id.resource_changed.connect (sigc::mem_fun (*this, &SelectorTriggerCanvasItem::update));
 }
 
-void SelectorTriggerCanvasItem::update ()
+void SelectorTriggerCanvasItem::draw (FooCanvasmm::Group &group) const
 {
-    if (group)
-	delete group;
-
-    group = new FooCanvasmm::Group (*draw_group, 0, 0);
-    
     int width = widget->get_width ();
     int height = widget->get_height ();
 
@@ -60,31 +53,31 @@ void SelectorTriggerCanvasItem::update ()
 	Gdk::Bitmap::create (stipple_bits, 2, 2);
     
     using namespace FooCanvasmm::Properties;
-    *(FormEditor::draw_rectangle (*group,
+    *(FormEditor::draw_rectangle (group,
 				  x1 - 1, y1 - 1,
 				  x2, y2))
 	<< width_units (1)
 	<< outline_stipple (stipple)
 	<< outline_color (get_foreground_color (widget->usable));
-    
-    int text_x = x1 + 3;
-    int text_y = y1;
 
-    if (widget->bitmap_id == "" && widget->selected_bitmap_id == "")
-        draw_text (*group,
-                   widget->text, get_font (widget->font),
-                   get_foreground_color (widget->usable),
-                   text_x, text_y, width - 3, height,
-                   Gtk::ANCHOR_WEST);
-    else
-        draw_bitmapref (*group, widget->bitmap_id,
-                        widget->get_manager ()->get_target ()->screen_color,
-                        get_background_color (),
-                        widget->x + 3, widget->y, 
-                        widget->get_width () - 3, widget->get_height (),
-                        Gtk::ANCHOR_WEST);
-    
-    set_canvas_item (group);
+    if (widget->get_width () > 3)
+    {
+        int text_x = x1 + 3;
+        int text_y = y1;
+        
+        if (widget->bitmap_id == "" && widget->selected_bitmap_id == "")
+            draw_text (group,
+                       widget->text, get_font (widget->font),
+                       get_foreground_color (widget->usable),
+                       text_x, text_y, width - 3, height,
+                       Gtk::ANCHOR_WEST);
+        else
+            draw_bitmapref (group,
+                            widget->bitmap_id, widget->get_manager ()->get_target ()->screen_color,
+                            get_background_color (),
+                            text_x, text_y, width - 3, height,
+                            Gtk::ANCHOR_WEST);
+    }
 }
 
 void SelectorTriggerCanvasItem::get_bounds (int &x1, int &y1,
