@@ -1,4 +1,4 @@
-//$Id: widget-factory.cc,v 1.4 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: widget-factory.cc,v 1.5 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -25,7 +25,7 @@ using namespace Guikachu::GUI::FormEditor;
 
 namespace
 {	    
-    class WidgetManager: public SigC::Object
+    class WidgetManager: public sigc::trackable
     {
     public:
 	typedef std::map<Widget*, CanvasItemManager*> item_manager_map_t;
@@ -78,7 +78,8 @@ WidgetCanvasItem * WidgetManager::get_canvas_item (Widget             *widget,
 	return found->second->get_canvas_item (group);
     
     if (editors.find (widget) == editors.end ())
-	widget->deleted.connect (SigC::bind (SigC::slot (*this, &WidgetManager::widget_deleted_cb), widget));
+	widget->deleted.connect (
+            sigc::bind (sigc::mem_fun (*this, &WidgetManager::widget_deleted_cb), widget));
     
     CanvasItemManager *item_manager = item_managers[widget] = new CanvasItemManager (widget);
     return item_manager->get_canvas_item (group);
@@ -91,7 +92,8 @@ Gtk::Widget * WidgetManager::get_editor (Widget *widget)
 	return found->second->get_editor ();
     
     if (item_managers.find (widget) == item_managers.end ())
-	widget->deleted.connect (SigC::bind (SigC::slot (*this, &WidgetManager::widget_deleted_cb), widget));
+	widget->deleted.connect (
+            sigc::bind (sigc::mem_fun (*this, &WidgetManager::widget_deleted_cb), widget));
     
     WidgetProperties *editor = editors[widget] = EditorFactoryVisitor (widget).get_result ();
     return editor->get_editor ();
