@@ -1,6 +1,6 @@
-//$Id: widget-ops.cc,v 1.7 2003/06/30 14:07:58 cactus Exp $ -*- c++ -*-
+//$Id: widget-ops.cc,v 1.9 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -40,7 +40,7 @@ RemoveOp::RemoveOp (Widget *widget):
     widget->apply_visitor (saver);
 }
 
-std::string RemoveOp::get_label () const
+Glib::ustring RemoveOp::get_label () const
 {
     return label;
 }
@@ -81,7 +81,7 @@ CreateOp::CreateOp (Widget *widget):
     g_free (tmp);
 }
 
-std::string CreateOp::get_label () const
+Glib::ustring CreateOp::get_label () const
 {
     return label;
 }
