@@ -1,6 +1,6 @@
-//$Id: widget-ops.h,v 1.6 2003/06/30 14:07:58 cactus Exp $ -*- c++ -*-
+//$Id: widget-ops.h,v 1.8 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -37,13 +37,13 @@ namespace Guikachu
 	    std::string   widget_id;
 	    StorageNode   node;
 	
-	    std::string          label;
+	    Glib::ustring   label;
 	
 	public:
 	    RemoveOp (Widget *widget);
 	    virtual ~RemoveOp () {};
 	
-	    std::string get_label () const;
+	    Glib::ustring get_label () const;
 	
 	    void undo ();
 	    void redo ();
@@ -59,13 +59,13 @@ namespace Guikachu
 	    std::string      widget_id;
 	    int              x, y;
 
-	    std::string      label;
+	    Glib::ustring    label;
 	
 	public:
 	    CreateOp (Widget *widget);
 	    virtual ~CreateOp () {};
 	
-	    std::string get_label () const;
+	    Glib::ustring get_label () const;
 	
 	    void undo ();
 	    void redo ();	
@@ -73,7 +73,7 @@ namespace Guikachu
 
 	class MultiMoveOp: public UndoOp
 	{
-	    std::string label;
+	    Glib::ustring label;
 	    
 	    ResourceManager *manager;
 	    
@@ -88,7 +88,7 @@ namespace Guikachu
 	    
 	    void undo ();
 	    void redo ();
-	    std::string get_label () const { return label; };
+	    Glib::ustring get_label () const { return label; };
 	};
 
 	
@@ -98,7 +98,7 @@ namespace Guikachu
 	    typedef std::set<real_op_t*> real_op_list_t;
 		
 	    real_op_list_t real_ops;
-	    std::string label;
+	    Glib::ustring label;
 	    
 	public:
 	    MultiRemoveOp (const std::set<Widget*> &widgets);
@@ -106,7 +106,7 @@ namespace Guikachu
 	    
 	    void undo ();
 	    void redo ();
-	    std::string get_label () const { return label; };
+	    Glib::ustring get_label () const { return label; };
 	};
 
     } // namespace WidgetOps
