@@ -1,4 +1,4 @@
-//$Id: widget-ref.h,v 1.10 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: widget-ref.h,v 1.11 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -20,7 +20,8 @@
 #define GUIKACHU_WIDGET_REF_H
 
 #include "property.h"
-#include <sigc++/object.h>
+#include <sigc++/trackable.h>
+#include <sigc++/connection.h>
 
 namespace Guikachu
 {
@@ -37,11 +38,11 @@ namespace Guikachu
     namespace Properties
     {
 	class WidgetRef: public Property<std::string>,
-			 public SigC::Object
+			 public sigc::trackable
 	{
 	    Resources::Form  *form;
 	    Widget           *current_widget;
-	    SigC::Connection  current_widget_changed;
+	    sigc::connection  current_widget_changed;
 	    
 	public:
 	    WidgetRef (notify_signal_t   &notify_signal,
@@ -54,7 +55,7 @@ namespace Guikachu
             Resources::Form * get_form () const { return form; };
             Widget *          resolve () const { return current_widget; };
 
-	    SigC::Signal0<void> widget_changed;
+	    sigc::signal0<void> widget_changed;
 	    
 	private:
 	    void widget_created_cb (Widget *widget);
