@@ -1,4 +1,4 @@
-//$Id: widget-util.cc,v 1.14 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: widget-util.cc,v 1.15 2004/06/27 11:06:11 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -23,22 +23,6 @@
 
 using namespace Guikachu;
 
-namespace {
-#include "pixmaps/label.xpm"
-#include "pixmaps/button.xpm"
-#include "pixmaps/pushbutton.xpm"
-#include "pixmaps/graffiti.xpm"
-#include "pixmaps/selector-trigger.xpm"
-#include "pixmaps/checkbox.xpm"
-#include "pixmaps/list.xpm"
-#include "pixmaps/popup-trigger.xpm"
-#include "pixmaps/scrollbar.xpm"
-#include "pixmaps/text-field.xpm"
-#include "pixmaps/table.xpm"
-#include "pixmaps/formbitmap.xpm"
-#include "pixmaps/gadget.xpm"
-}
-
 const std::string Widgets::prefix_from_type (Widgets::Type type)
 {
     g_return_val_if_fail (type != Widgets::WIDGET_NONE, "");
@@ -187,46 +171,7 @@ Widgets::Type Widgets::type_from_type_id (const std::string &type_id)
     return type;
 }
 
-const char * const * Widgets::type_icon (Widgets::Type type)
-{
-    g_return_val_if_fail (type != Widgets::WIDGET_NONE, NULL);
-
-    switch (type)
-    {
-    case Widgets::WIDGET_BUTTON:
-	return button_xpm;
-    case Widgets::WIDGET_CHECKBOX:
-	return checkbox_xpm;
-    case Widgets::WIDGET_GRAFFITI:
-	return graffiti_xpm;
-    case Widgets::WIDGET_LABEL:
-	return label_xpm;
-    case Widgets::WIDGET_LIST:
-	return list_xpm;
-    case Widgets::WIDGET_POPUP_TRIGGER:
-	return popup_trigger_xpm;
-    case Widgets::WIDGET_PUSHBUTTON:
-	return pushbutton_xpm;
-    case Widgets::WIDGET_SCROLLBAR:
-	return scrollbar_xpm;
-    case Widgets::WIDGET_SELECTOR_TRIGGER:
-	return selector_trigger_xpm;
-    case Widgets::WIDGET_TEXT_FIELD:
-	return text_field_xpm;
-    case Widgets::WIDGET_TABLE:
-	return table_xpm;
-    case Widgets::WIDGET_FORMBITMAP:
-        return formbitmap_xpm;
-    case Widgets::WIDGET_GADGET:
-	return gadget_xpm;
-    case Widgets::WIDGET_NONE:
-	g_assert_not_reached ();
-    }
-
-    return NULL;
-}
-
-const std::string Widgets::display_name_from_type (Widgets::Type type)
+const Glib::ustring Widgets::display_name_from_type (Widgets::Type type)
 {
     std::string disp_name;
     
