@@ -1,4 +1,4 @@
-//$Id: widget-util.h,v 1.8 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: widget-util.h,v 1.9 2004/06/27 11:06:11 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -27,13 +27,12 @@ namespace Guikachu
 {
     namespace Widgets
     {
-	const std::string prefix_from_type       (Type               type) G_GNUC_CONST;
+	const std::string   prefix_from_type       (Type               type) G_GNUC_CONST;
 
-	const std::string type_id_from_type      (Type               type) G_GNUC_CONST;
-	Type              type_from_type_id      (const std::string &type_id);
+	const std::string   type_id_from_type      (Type               type) G_GNUC_CONST;
+	Type                type_from_type_id      (const std::string &type_id);
 
-	const std::string display_name_from_type (Type               type) G_GNUC_CONST;
-	const char * const * type_icon           (Type               type) G_GNUC_CONST;
+	const Glib::ustring display_name_from_type (Type               type) G_GNUC_CONST;
     }
 }
 
