@@ -1,4 +1,4 @@
-//$Id: form-res.cc,v 1.46 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: form-res.cc,v 1.47 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -160,7 +160,7 @@ Widget* Form::create_widget (Widgets::Type type,
     }
 
     widgets[serial] = widget;
-    widget->changed.connect (widget_changed.slot());
+    widget->changed.connect (widget_changed.make_slot());
     
     widget_created (widget);
 
