@@ -1,4 +1,4 @@
-//$Id: form-win-helpers.cc,v 1.22 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: form-win-helpers.cc,v 1.23 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -40,16 +40,14 @@ CanvasSelectionWrapper::CanvasSelectionWrapper (FooCanvasmm::Canvas &canvas_):
     dragging (false),
     active (true)
 {
-    using namespace SigC;
-
     canvas.signal_button_press_event ().connect_notify (
-	slot (*this, &CanvasSelectionWrapper::selection_begin),
+	sigc::mem_fun (*this, &CanvasSelectionWrapper::selection_begin),
         true); // true == connect_after
     canvas.signal_motion_notify_event ().connect_notify (
-	slot (*this, &CanvasSelectionWrapper::selection_drag),
+	sigc::mem_fun (*this, &CanvasSelectionWrapper::selection_drag),
         true); // true == connect_after
     canvas.signal_button_release_event ().connect_notify (
-	slot (*this, &CanvasSelectionWrapper::selection_end),
+	sigc::mem_fun (*this, &CanvasSelectionWrapper::selection_end),
         true); // true == connect_after
 }
 
