@@ -1,4 +1,4 @@
-//$Id: form-win-propedit.cc,v 1.5 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: form-win-propedit.cc,v 1.6 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -50,7 +50,7 @@ void FormWindow::show_property_editor (Widget *widget)
     // Update property editor window's title
     edited_widget_changed_conn.disconnect ();
     edited_widget_changed_conn = edited_widget->changed.connect (
-	SigC::slot (*this, &FormWindow::edited_widget_changed));
+	sigc::mem_fun (*this, &FormWindow::edited_widget_changed));
     edited_widget_changed ();
 
     // Change property editor
