@@ -1,4 +1,4 @@
-//$Id: form-win-widgettree.h,v 1.3 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: form-win-widgettree.h,v 1.5 2004/06/26 17:00:43 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -33,12 +33,11 @@ namespace Guikachu
     {
 	namespace FormWindow_Helpers
 	{
-	    class WidgetTreeWrapper: public SigC::Object
+	    class WidgetTreeWrapper: public sigc::trackable
 	    {
 		Gtk::TreeView   &treeview;
 		Resources::Form *form;
 		
-		Gtk::TreeModelColumn<Glib::ustring>     col_label;
 		Gtk::TreeModelColumn<Guikachu::Widget*> col_widget;
 		Glib::RefPtr<Gtk::TreeStore>            treestore;
 		
@@ -54,14 +53,16 @@ namespace Guikachu
 		WidgetTreeWrapper (Gtk::TreeView   &treeview,
 				   Resources::Form *form);
 
-		SigC::Signal0<void>                 form_selected;
-                SigC::Signal2<void, guint, guint32> form_menu;
+		sigc::signal0<void>                 form_selected;
+                sigc::signal2<void, guint, guint32> form_menu;
                 
-		SigC::Signal2<void, Guikachu::Widget*, bool>           widget_selected;
-                SigC::Signal1<void, Guikachu::Widget*>                 widget_remove;
-		SigC::Signal3<void, guint, guint32, Guikachu::Widget*> widget_menu;
+		sigc::signal2<void, Guikachu::Widget*, bool>           widget_selected;
+                sigc::signal1<void, Guikachu::Widget*>                 widget_remove;
+		sigc::signal3<void, guint, guint32, Guikachu::Widget*> widget_menu;
 		
 	    private:
+                void cell_label_cb (Gtk::CellRenderer *cell, const Gtk::TreeModel::iterator &iter) const;
+                
 		void form_changed_cb ();
 		
 		void widget_created_cb (Guikachu::Widget *widget);
