@@ -1,6 +1,6 @@
-//$Id: guikachu2rcp.cc,v 1.6 2004/03/31 17:55:00 cactus Exp $ -*- c++ -*-
+//$Id: guikachu2rcp.cc,v 1.8 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -17,7 +17,7 @@
  */
 
 #include "config.h"
-#include <libgnome/libgnome.h>
+#include "gnome-i18n-cnp.h"
 
 #include <libgnomevfs/gnome-vfs.h>
 
