@@ -1,4 +1,4 @@
-//$Id: io.cc,v 1.8 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: io.cc,v 1.9 2004/07/12 22:07:58 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -23,7 +23,8 @@
 #include "io/rcp-loader.h"
 #include "io/rcp-saver.h"
 
-#include <libgnomevfs/gnome-vfs-mime-utils.h>
+#include <libgnomevfsmm/uri.h>
+#include <libgnomevfsmm/utils.h>
 
 using namespace Guikachu;
 
@@ -44,12 +45,15 @@ Glib::ustring IO::create_canonical_uri (const Glib::ustring &filename)
 	full_filename = Glib::ustring (current_dirname) + "/" + filename;
 	g_free (current_dirname);
     }
-    
-    char *uri_tmp = gnome_vfs_make_uri_canonical (full_filename.c_str ());
-    Glib::ustring uri = uri_tmp;
-    g_free (uri_tmp);
-    
-    return uri;
+
+    return Gnome::Vfs::make_uri_canonical (full_filename);
+}
+
+Glib::ustring IO::get_mime_type (const Glib::ustring &uri)
+{
+    Glib::RefPtr<Gnome::Vfs::Uri> vfs_uri = Gnome::Vfs::Uri::create (uri);
+    Glib::RefPtr<Gnome::Vfs::FileInfo> file_info = vfs_uri->get_file_info (Gnome::Vfs::FILE_INFO_GET_MIME_TYPE);
+    return file_info->get_mime_type ();
 }
 
 IO::IOResult IO::load_uri (const Glib::ustring &uri, char *&data, GnomeVFSFileSize &len)
