@@ -1,6 +1,6 @@
-//$Id: rcp-loader.h,v 1.3 2004/03/21 17:55:38 cactus Exp $ -*- c++ -*-
+//$Id: rcp-loader.h,v 1.5 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -28,7 +28,7 @@ namespace Guikachu
 	class RCPLoader: public Loader
 	{
 	public:
-	    IOResult load (ResourceManager *manager, const std::string &uri);
+	    IOResult load (ResourceManager *manager, const Glib::ustring &uri);
 	};
 	
     }
