@@ -1,4 +1,4 @@
-//$Id: xml-loader.cc,v 1.11 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: xml-loader.cc,v 1.12 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,8 +21,6 @@
 #include "config.h"
 #include "gnome-i18n-cnp.h"
 
-#include <sigc++/object_slot.h>
-
 #include <libxml/parser.h>
 
 #include <libgnomevfs/gnome-vfs.h>
@@ -74,7 +72,7 @@ IOResult XMLLoader::load (ResourceManager *manager, const Glib::ustring &uri)
     encoding_fixed = false;
 
     // Set up callbacks
-    storage.encoding_notify.connect (SigC::slot (*this, &XMLLoader::encoding_fixed_cb));
+    storage.encoding_notify.connect (sigc::mem_fun (*this, &XMLLoader::encoding_fixed_cb));
 
     manager->block_dirty ();
     
