@@ -1,4 +1,4 @@
-//$Id: xml-loader.h,v 1.7 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: xml-loader.h,v 1.8 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -24,13 +24,13 @@
 #include "resource-visitor.h"
 #include "form-editor/widget-visitor.h"
 
-#include <sigc++/object.h>
+#include <sigc++/trackable.h>
 
 namespace Guikachu
 {
     namespace IO
     {
-	class XMLLoader: public SigC::Object,
+	class XMLLoader: public sigc::trackable,
 			 public Loader
 	{
 	    bool encoding_fixed;
