@@ -1,6 +1,6 @@
-//$Id: menu-res.h,v 1.23 2004/01/30 01:08:56 cactus Exp $ -*- c++ -*-
+//$Id: menu-res.h,v 1.25 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -37,11 +37,13 @@ namespace Guikachu
 		std::string label;
 		char        shortcut;
 	    };
+
+	    typedef std::vector<MenuItem> MenuItems;
 	    
 	    struct Submenu
 	    {
-		std::string           label;
-		std::vector<MenuItem> items;
+		std::string label;
+		MenuItems   items;
 		
 		Submenu () {};
 		Submenu (const std::string& label);
