@@ -1,4 +1,4 @@
-//$Id: menu-win.cc,v 1.35 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: menu-win.cc,v 1.42 2004/07/08 11:27:49 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -24,13 +24,15 @@
 #include "property-ops-resource.h"
 #include "menu-res-ops.h"
 
-#include <sigc++/hide.h>
-#include <sigc++/bind.h>
-#include <sigc++/bind_return.h>
+#include <sigc++/adaptors/hide.h>
+#include <sigc++/adaptors/bind.h>
+#include <sigc++/adaptors/bind_return.h>
 
 #include "ui.h"
 #include "property-ops.h"
 
+#include "cellrenderer-indent.h"
+
 using namespace Guikachu;
 using namespace Guikachu::ResourceOps::MenuOps;
 
@@ -40,19 +42,14 @@ GUI::MenuWindow::MenuWindow (Guikachu::Resources::Menu *res_):
     current_entry (0),
     update_block (0)
 {
-    using namespace SigC;
-
     gui->get_widget ("res_menu", window);
-    window->signal_delete_event ().connect (bind_return (
-	slot (*this, &MenuWindow::delete_event_impl), true));    
+    window->signal_delete_event ().connect (sigc::bind_return (
+        sigc::mem_fun (*this, &MenuWindow::delete_event_impl), true));    
     
     gui->get_widget ("menu_id", id_entry);
 
     // Menu items list
     Gtk::TreeModel::ColumnRecord cols;
-    cols.add (col_label);
-    cols.add (col_id);
-    cols.add (col_shortcut);
     cols.add (col_is_submenu);
     cols.add (col_index);
     cols.add (col_parent_index);
@@ -60,12 +57,29 @@ GUI::MenuWindow::MenuWindow (Guikachu::Resources::Menu *res_):
 
     gui->get_widget ("menu_tree", treeview);
     treeview->set_model (treestore);
-    treeview->append_column (_("Label"), col_label);
-    treeview->append_column (_("ID"), col_id);
-    treeview->append_column (_("Shortcut"), col_shortcut);
+
+    CellRendererIndent<Gtk::CellRendererText> *indent_renderer = new CellRendererIndent<Gtk::CellRendererText>;
+    Gtk::CellRendererText *label_renderer = static_cast<Gtk::CellRendererText*> (indent_renderer->get_real_cell ());
+    Gtk::TreeView::Column *label_col = new Gtk::TreeView::Column (_("Label"), *manage (indent_renderer));
+    label_col->set_cell_data_func (*indent_renderer, sigc::mem_fun (*this, &MenuWindow::cell_label_cb));
+    label_renderer->signal_edited ().connect (sigc::mem_fun (*this, &MenuWindow::cell_label_edit_cb));
+    treeview->append_column (*manage (label_col));
+
+    Gtk::CellRendererText *id_renderer = new Gtk::CellRendererText;
+    Gtk::TreeView::Column *id_col = new Gtk::TreeView::Column (_("ID"), *manage (id_renderer));
+    id_col->set_cell_data_func (*id_renderer, sigc::mem_fun (*this, &MenuWindow::cell_id_cb));
+    id_renderer->signal_edited ().connect (sigc::mem_fun (*this, &MenuWindow::cell_id_edit_cb));
+    treeview->append_column (*manage (id_col));
+
+    Gtk::CellRendererText *shortcut_renderer = new Gtk::CellRendererText;
+    Gtk::TreeView::Column *shortcut_col = new Gtk::TreeView::Column (_("Shortcut"), *manage (shortcut_renderer));
+    shortcut_col->set_cell_data_func (*shortcut_renderer, sigc::mem_fun (*this, &MenuWindow::cell_shortcut_cb));
+    shortcut_renderer->signal_edited ().connect (sigc::mem_fun (*this, &MenuWindow::cell_shortcut_edit_cb));
+    treeview->append_column (*manage (shortcut_col));
+    
     treeview->get_selection ()->set_mode (Gtk::SELECTION_BROWSE);
     treeview->get_selection ()->signal_changed ().connect (
-	SigC::slot (*this, &MenuWindow::selection_changed_cb));
+	sigc::mem_fun (*this, &MenuWindow::selection_changed_cb));
     
     gui->get_widget ("menu_btn_up", btnUp);
     gui->get_widget ("menu_btn_down", btnDown);
@@ -84,31 +98,35 @@ GUI::MenuWindow::MenuWindow (Guikachu::Resources::Menu *res_):
     gui->get_widget ("menuitem_shortcut", item_shortcut);
     gui->get_widget ("menuitem_shortcut_label", lbl_item_shortcut);
 
-    id_entry->signal_activate ().connect (slot (*this, &MenuWindow::id_entry_cb));
+    id_entry->signal_activate ().connect (sigc::mem_fun (*this, &MenuWindow::id_entry_cb));
     id_entry->signal_focus_out_event ().connect (
-	hide<GdkEventFocus*> (bind_return (slot (*this, &MenuWindow::id_entry_cb), false)));
+	sigc::hide (sigc::bind_return (sigc::mem_fun (*this, &MenuWindow::id_entry_cb), false)));
     
-    item_id->signal_activate ().connect (slot (*this, &MenuWindow::item_id_entry_cb));
+    item_id->signal_activate ().connect (sigc::mem_fun (*this, &MenuWindow::item_id_entry_cb));
     item_id->signal_focus_out_event ().connect (
-        hide<GdkEventFocus*> (bind_return (slot (*this, &MenuWindow::item_id_entry_cb), false)));
+        sigc::hide (sigc::bind_return (sigc::mem_fun (*this, &MenuWindow::item_id_entry_cb), false)));
 
-    item_label->signal_changed ().connect (slot (*this, &MenuWindow::item_label_entry_cb));
-    item_label->signal_insert_text ().connect_notify (bind (slot (*this, &MenuWindow::entry_insert_cb), item_label));
-    item_label->signal_delete_text ().connect_notify (bind (slot (*this, &MenuWindow::entry_delete_cb), item_label));
+    item_label->signal_changed ().connect (sigc::mem_fun (*this, &MenuWindow::item_label_entry_cb));
+    item_label->signal_insert_text ().connect_notify (
+        sigc::bind (sigc::mem_fun (*this, &MenuWindow::entry_insert_cb), item_label));
+    item_label->signal_delete_text ().connect_notify (
+        sigc::bind (sigc::mem_fun (*this, &MenuWindow::entry_delete_cb), item_label));
 
-    item_shortcut->signal_changed ().connect (slot (*this, &MenuWindow::item_shortcut_entry_cb));
-    item_shortcut->signal_insert_text ().connect_notify (bind (slot (*this, &MenuWindow::entry_insert_cb), item_shortcut));
-    item_shortcut->signal_delete_text ().connect_notify (bind (slot (*this, &MenuWindow::entry_delete_cb), item_shortcut));
+    item_shortcut->signal_changed ().connect (sigc::mem_fun (*this, &MenuWindow::item_shortcut_entry_cb));
+    item_shortcut->signal_insert_text ().connect_notify (
+        sigc::bind (sigc::mem_fun (*this, &MenuWindow::entry_insert_cb), item_shortcut));
+    item_shortcut->signal_delete_text ().connect_notify (
+        sigc::bind (sigc::mem_fun (*this, &MenuWindow::entry_delete_cb), item_shortcut));
 
-    btnUp->signal_clicked ().connect (slot (*this, &MenuWindow::btn_up_cb));
-    btnDown->signal_clicked ().connect (slot (*this, &MenuWindow::btn_down_cb));
-    btnRemove->signal_clicked ().connect (slot (*this, &MenuWindow::btn_remove_cb));
+    btnUp->signal_clicked ().connect (sigc::mem_fun (*this, &MenuWindow::btn_up_cb));
+    btnDown->signal_clicked ().connect (sigc::mem_fun (*this, &MenuWindow::btn_down_cb));
+    btnRemove->signal_clicked ().connect (sigc::mem_fun (*this, &MenuWindow::btn_remove_cb));
 
-    btnSubmenu->signal_clicked ().connect (slot (*this, &MenuWindow::btn_submenu_cb));
-    btnItem->signal_clicked ().connect (bind (slot (*this, &MenuWindow::btn_item_cb), false));
-    btnSeparator->signal_clicked ().connect (bind (slot (*this, &MenuWindow::btn_item_cb), true));
+    btnSubmenu->signal_clicked ().connect (sigc::mem_fun (*this, &MenuWindow::btn_submenu_cb));
+    btnItem->signal_clicked ().connect (sigc::bind (sigc::mem_fun (*this, &MenuWindow::btn_item_cb), false));
+    btnSeparator->signal_clicked ().connect (sigc::bind (sigc::mem_fun (*this, &MenuWindow::btn_item_cb), true));
     
-    res->changed.connect (slot (*this, &MenuWindow::update));
+    res->changed.connect (sigc::mem_fun (*this, &MenuWindow::update));
     update ();
 }
 
@@ -117,6 +135,103 @@ GUI::MenuWindow::~MenuWindow ()
     delete window;
 }
 
+void GUI::MenuWindow::cell_label_cb (Gtk::CellRenderer *cell, const Gtk::TreeModel::iterator &iter) const
+{
+    typedef Gtk::CellRendererText text_cell_t;
+    typedef CellRendererIndent<text_cell_t> indent_cell_t;
+    
+    indent_cell_t *cell_indent = dynamic_cast<indent_cell_t*> (cell);
+    g_return_if_fail (cell_indent);
+    
+    text_cell_t *cell_text = dynamic_cast<text_cell_t*> (cell_indent->get_real_cell ());
+    g_return_if_fail (cell_text);
+
+    if ((*iter)[col_is_submenu])
+    {
+        const Resources::Menu::Submenu &submenu = submenus[(*iter)[col_index]];
+
+        cell_indent->set_depth (0);
+        cell_text->property_text () = submenu.label;
+        cell_text->property_weight () = Pango::WEIGHT_BOLD;
+        cell_text->property_editable () = true;
+    } else {
+        const Resources::Menu::MenuItem &item = submenus[(*iter)[col_parent_index]].items[(*iter)[col_index]];
+
+        cell_indent->set_depth (1);
+        cell_text->property_weight () = Pango::WEIGHT_NORMAL;
+
+        if (item.separator)
+        {
+            cell_text->property_text () = "------";
+            cell_text->property_editable () = false;
+        } else {
+            cell_text->property_text () = item.label;
+            cell_text->property_editable () = true;
+        }
+    }
+}
+
+void GUI::MenuWindow::cell_id_cb (Gtk::CellRenderer *cell, const Gtk::TreeModel::iterator &iter) const
+{
+    Gtk::CellRendererText *cell_id = dynamic_cast<Gtk::CellRendererText*> (cell);
+    g_return_if_fail (cell_id);
+
+    if ((*iter)[col_is_submenu])
+    {
+        cell_id->property_text () = "";
+        cell_id->property_editable () = false;
+    } else {
+        const Resources::Menu::MenuItem &item = submenus[(*iter)[col_parent_index]].items[(*iter)[col_index]];
+        cell_id->property_text () = item.separator ? "" : item.id;
+        cell_id->property_editable () = !item.separator;
+    }
+}
+
+void GUI::MenuWindow::cell_shortcut_cb (Gtk::CellRenderer *cell, const Gtk::TreeModel::iterator &iter) const
+{
+    Gtk::CellRendererText *cell_shortcut = dynamic_cast<Gtk::CellRendererText*> (cell);
+    g_return_if_fail (cell_shortcut);
+
+    cell_shortcut->property_text () = "";
+    cell_shortcut->property_editable () = false;
+    
+    if ((*iter)[col_is_submenu])
+        return;
+
+    const Resources::Menu::MenuItem &item = submenus[(*iter)[col_parent_index]].items[(*iter)[col_index]];
+    cell_shortcut->property_editable () = !item.separator;
+    
+    if (!item.separator && item.shortcut)
+    {
+        Glib::ScopedPtr<char> shortcut_str (g_strdup_printf ("%c", item.shortcut));
+        cell_shortcut->property_text () = shortcut_str.get ();
+    }
+}
+
+void GUI::MenuWindow::cell_label_edit_cb (const Glib::ustring &path, const Glib::ustring &new_text)
+{
+    current_entry = 0;
+    
+    Gtk::TreeModel::iterator iter = treestore->get_iter (path);    
+    set_item_label (iter, new_text);
+}
+
+void GUI::MenuWindow::cell_id_edit_cb (const Glib::ustring &path, const Glib::ustring &new_text)
+{
+    current_entry = 0;
+    
+    Gtk::TreeModel::iterator iter = treestore->get_iter (path);    
+    set_item_id (iter, new_text);
+}
+
+void GUI::MenuWindow::cell_shortcut_edit_cb (const Glib::ustring &path, const Glib::ustring &new_text)
+{
+    current_entry = 0;
+    
+    Gtk::TreeModel::iterator iter = treestore->get_iter (path);    
+    set_item_shortcut (iter, new_text);
+}
+
 void GUI::MenuWindow::delete_event_impl (GdkEventAny *e)
 {
     window->hide ();
@@ -149,41 +264,21 @@ void GUI::MenuWindow::update ()
         if (!store_iter)
             store_iter = treestore->append ();
         Gtk::TreeRow row (*store_iter);
-        
-	row[col_label] = Glib::ustring (i->label);
-        row[col_id] = "";
-        row[col_shortcut] = "";
+
 	row[col_is_submenu] = true;
 	row[col_index] = submenu_num;
 
         ++store_path[0];
         
-	unsigned int menuitem_num = 0;
-	for (Resources::Menu::MenuItems::const_iterator j = i->items.begin ();
-	     j != i->items.end (); ++j, ++menuitem_num)
+        for (unsigned int j = 0; j < i->items.size (); ++j)
 	{
             Gtk::TreeModel::iterator store_iter = treestore->get_iter (store_path);
             if (!store_iter)
                 store_iter = treestore->append ();
             row = *store_iter;
 
-	    if (!j->separator)
-	    {
-		gchar *shortcut_str = g_strdup_printf ("%c", j->shortcut);
-
-		row[col_label] = ("    " + Glib::ustring (j->label));
-		row[col_id] = Glib::ustring (j->id);
-		row[col_shortcut] = shortcut_str;
-
-		g_free (shortcut_str);		
-	    } else {
-		row[col_label] = "    ------";
-                row[col_id] = "";
-                row[col_shortcut] = "";
-	    }
-
 	    row[col_is_submenu] = false;
-	    row[col_index] = menuitem_num;
+	    row[col_index] = j;
 	    row[col_parent_index] = submenu_num;
 
             ++store_path[0];
@@ -260,7 +355,6 @@ void GUI::MenuWindow::selection_changed_cb ()
 	item_label->set_text (submenu.label);
 	item_label->set_sensitive (true);
 	lbl_item_label->set_sensitive (true);
-
     } else {
 	// This is a menu item
 	unsigned int index = (*iter)[col_index];
@@ -317,7 +411,7 @@ void GUI::MenuWindow::id_entry_cb ()
     if (update_block)
 	return;
 
-    static ResourceOps::RenameOpFactory op_factory (res);
+    ResourceOps::RenameOpFactory op_factory (res);
 
     const std::string new_id = id_entry->get_text ();
     op_factory.push_change (new_id);
@@ -325,45 +419,43 @@ void GUI::MenuWindow::id_entry_cb ()
     id_entry->set_text (Glib::ustring (res->id));
 }
 
-void GUI::MenuWindow::item_id_entry_cb ()
-{
-    if (update_block)
-	return;
-    
-    Gtk::TreeModel::iterator iter = treeview->get_selection ()->get_selected ();
-    if (!iter)
-        return;
-
-    unsigned int index = (*iter)[col_index];
-    unsigned int parent_index = (*iter)[col_parent_index];    
-    const std::string new_id = item_id->get_text ();
-
-    if ((*iter)[col_is_submenu])
-	return;
-
-    std::vector<Resources::Menu::MenuItem>& items = submenus[parent_index].items;
-
-    if (items[index].id == new_id)
-	return;
-    
-    items[index].id = new_id;
-
-    UndoOp *op = new MenuItemRenameOp (res, parent_index, index, new_id);
-    res->set_submenus (submenus);
-    res->get_manager ()->get_undo_manager ().push (op);
-}
-
 void GUI::MenuWindow::item_label_entry_cb ()
 {
     if (update_block)
 	return;
     
     Gtk::TreeModel::iterator iter = treeview->get_selection ()->get_selected ();
+    const std::string new_label = item_label->get_text ();
+
+    set_item_label (iter, new_label);
+}
+
+void GUI::MenuWindow::item_id_entry_cb ()
+{
+    if (update_block)
+	return;
+    
+    Gtk::TreeModel::iterator iter = treeview->get_selection ()->get_selected ();
+    const std::string new_id = item_id->get_text ();
+
+    set_item_id (iter, new_id);
+}
+
+void GUI::MenuWindow::item_shortcut_entry_cb ()
+{
+    if (update_block)
+	return;
+    
+    Gtk::TreeModel::iterator iter = treeview->get_selection ()->get_selected ();
+    set_item_shortcut (iter, item_shortcut->get_text ());
+}
+
+void GUI::MenuWindow::set_item_label (const Gtk::TreeModel::iterator &iter, const std::string &new_label)
+{
     if (!iter)
         return;
 
     unsigned int index = (*iter)[col_index];
-    const std::string new_label = item_label->get_text ();
 
     if ((*iter)[col_is_submenu])
     {
@@ -391,12 +483,31 @@ void GUI::MenuWindow::item_label_entry_cb ()
     }
 }
 
-void GUI::MenuWindow::item_shortcut_entry_cb ()
+void GUI::MenuWindow::set_item_id (const Gtk::TreeModel::iterator &iter, const std::string &new_id)
 {
-    if (update_block)
+    if (!iter)
+        return;
+
+    unsigned int index = (*iter)[col_index];
+    unsigned int parent_index = (*iter)[col_parent_index];    
+
+    if ((*iter)[col_is_submenu])
+	return;
+
+    std::vector<Resources::Menu::MenuItem>& items = submenus[parent_index].items;
+
+    if (items[index].id == new_id)
 	return;
     
-    Gtk::TreeModel::iterator iter = treeview->get_selection ()->get_selected ();
+    items[index].id = new_id;
+
+    UndoOp *op = new MenuItemRenameOp (res, parent_index, index, new_id);
+    res->set_submenus (submenus);
+    res->get_manager ()->get_undo_manager ().push (op);
+}
+
+void GUI::MenuWindow::set_item_shortcut (const Gtk::TreeModel::iterator &iter, const std::string &new_shortcut)
+{
     if (!iter)
         return;
 
@@ -406,9 +517,7 @@ void GUI::MenuWindow::item_shortcut_entry_cb ()
     unsigned int parent_index = (*iter)[col_parent_index];
 
     std::vector<Resources::Menu::MenuItem>& items = submenus[parent_index].items;
-    std::string shortcut_str = item_shortcut->get_text ();
-    char shortcut = shortcut_str == "" ? 0 : shortcut_str[0];    
-
+    char shortcut = new_shortcut == "" ? 0 : new_shortcut[0];
     
     if (shortcut == items[index].shortcut)
 	return;
