@@ -1,4 +1,4 @@
-//$Id: preferences.h,v 1.11 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: preferences.h,v 1.13 2004/07/12 22:07:57 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -32,19 +32,18 @@ namespace Guikachu
 
 	namespace Interface
 	{
-	    extern SigC::Signal0<void> recent_files_changed;
-	    typedef std::pair<Glib::ustring, std::string> RecentFileEntry;
-	    typedef std::list<RecentFileEntry> RecentFiles;
+	    extern sigc::signal0<void> recent_files_changed;
+	    typedef std::list<Glib::ustring> RecentFiles;
 	    
 	    RecentFiles get_recent_files ();
-	    void add_recent_file (const RecentFileEntry &entry);
+	    void add_recent_file (const Glib::ustring &uri);
 
 	    int get_undo_size ();
 	}
 	
 	namespace FormEditor
 	{
-	    extern SigC::Signal0<void> colors_changed;
+	    extern sigc::signal0<void> colors_changed;
 	    std::string get_color_fg ();
 	    std::string get_color_disabled ();
 	    std::string get_color_bg ();
