@@ -1,4 +1,4 @@
-//$Id: queued-signal.cc,v 1.5 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: queued-signal.cc,v 1.6 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  *
@@ -30,7 +30,7 @@ using namespace Guikachu;
 
 namespace
 {
-    void default_queuer (SigC::Slot0<void> slot)
+    void default_queuer (VSignal::slot_t slot)
     {
 	slot ();
     }
@@ -54,7 +54,7 @@ void QueuedSignal::emit ()
     if (!queued)
     {
         queued = true;
-	signal_queuer (SigC::slot (*this, &QueuedSignal::idle_cb));
+	signal_queuer (sigc::mem_fun (*this, &QueuedSignal::idle_cb));
     }
 
 }
