@@ -1,4 +1,4 @@
-//$Id: resource-manager.h,v 1.33 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: resource-manager.h,v 1.34 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -34,12 +34,12 @@ namespace Guikachu
 
 #include <set>
 #include <sigc++/signal.h>
-#include <sigc++/object.h>
+#include <sigc++/trackable.h>
 #include <time.h>
 
 namespace Guikachu
 {
-    class ResourceManager: public IDManager, public SigC::Object
+    class ResourceManager: public IDManager, public sigc::trackable
     {
     public:
 	typedef std::map<serial_t, Resource*> resource_map_t;
@@ -74,9 +74,9 @@ namespace Guikachu
 	UndoManager& get_undo_manager () { return undo_manager; };
 	
 	// Signals
-	SigC::Signal1<void, Resource*> resource_created;
-	SigC::Signal1<void, Resource*> resource_removed;
-	SigC::Signal0<void> dirty_state_changed;
+	sigc::signal1<void, Resource*> resource_created;
+	sigc::signal1<void, Resource*> resource_removed;
+	sigc::signal0<void> dirty_state_changed;
 	
 	bool   is_dirty () const;
 	time_t get_modification_time ();
