@@ -1,4 +1,4 @@
-//$Id: resource-ref.cc,v 1.11 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: resource-ref.cc,v 1.12 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -18,8 +18,6 @@
 
 #include "resource-ref.h"
 
-#include <sigc++/sigc++.h>
-
 using namespace Guikachu::Properties;
 using std::string;
 
@@ -33,10 +31,10 @@ ResourceRef::ResourceRef (notify_signal_t &notify_signal,
 
     if (current_resource)
 	current_resource_changed = current_resource->changed.connect (
-	    SigC::slot (*this, &ResourceRef::resource_changed_cb));
+	    sigc::mem_fun (*this, &ResourceRef::resource_changed_cb));
 
-    manager->resource_created.connect (SigC::slot (*this, &ResourceRef::resource_created_cb));
-    manager->resource_removed.connect (SigC::slot (*this, &ResourceRef::resource_removed_cb));
+    manager->resource_created.connect (sigc::mem_fun (*this, &ResourceRef::resource_created_cb));
+    manager->resource_removed.connect (sigc::mem_fun (*this, &ResourceRef::resource_removed_cb));
 }
 
 void ResourceRef::set_val (const string &value_)
@@ -53,7 +51,7 @@ void ResourceRef::set_val (const string &value_)
 
 	if (current_resource)
 	    current_resource_changed = current_resource->changed.connect (
-		SigC::slot (*this, &ResourceRef::resource_changed_cb));
+		sigc::mem_fun (*this, &ResourceRef::resource_changed_cb));
     }
 
     Property<string>::set_val (value_);
@@ -66,7 +64,7 @@ void ResourceRef::resource_created_cb (Resource *res)
 	current_resource = res;
 	current_resource_changed.disconnect ();
 	current_resource_changed = current_resource->changed.connect (
-	    SigC::slot (*this, &ResourceRef::resource_changed_cb));
+	    sigc::mem_fun (*this, &ResourceRef::resource_changed_cb));
     }
 }
 
