@@ -1,4 +1,4 @@
-//$Id: resource-tree.cc,v 1.10 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id$ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -25,13 +25,16 @@
 #include "resource-manager-ops.h"
 #include "edit-cut-and-paste.h"
 
+#include "cellrenderer-icontext.h"
+#include "cellrenderer-indent.h"
+
 #include <libgnomeuimm/app-helper.h>
 #include <libgnomeuimm/ui-items-stock.h>
 #include <libgnomeuimm/app-helper.h>
 #include <gtkmm/stock.h>
 
-#include <sigc++/bind.h>
-#include <sigc++/bind_return.h>
+#include <sigc++/adaptors/bind.h>
+#include <sigc++/adaptors/bind_return.h>
 
 #include <algorithm>
 #include <functional>
@@ -72,22 +75,23 @@ ResourceTree::ResourceTree ():
     popup_menu (0)
 {
     Gtk::TreeModel::ColumnRecord cols;
-    cols.add (col_label);
-    cols.add (col_res);
+    cols.add (col_data);
     
     treestore = Gtk::TreeStore::create (cols);
     set_model (treestore);
-    
-    append_column ("", col_label);
-    set_headers_visible (false);
 
+    set_headers_visible (false);
+    
+    CellRendererIndent<CellRendererIconText>::setup_view (
+        *this, "", sigc::mem_fun (*this, &ResourceTree::cell_label_cb));
+    
     /* Connect to events */
-    signal_button_press_event ().connect_notify (slot (*this, &ResourceTree::button_press_cb));
-    signal_key_press_event ().connect (bind_return (slot (*this, &ResourceTree::key_press_cb), true));
+    signal_button_press_event ().connect_notify (sigc::mem_fun (*this, &ResourceTree::button_press_cb));
+    signal_key_press_event ().connect (sigc::bind_return (sigc::mem_fun (*this, &ResourceTree::key_press_cb), true));
 
     add_events (Gdk::BUTTON_PRESS_MASK | Gdk::KEY_PRESS_MASK);
 
-    signal_row_activated ().connect (slot (*this, &ResourceTree::row_activated_cb));    
+    signal_row_activated ().connect (sigc::mem_fun (*this, &ResourceTree::row_activated_cb));    
 }
 
 ResourceTree::~ResourceTree ()
@@ -96,6 +100,12 @@ ResourceTree::~ResourceTree ()
     delete app_win;
 }
 
+void ResourceTree::cell_label_cb (Gtk::CellRenderer *cell, const Gtk::TreeModel::iterator &iter) const
+{
+    const TreeData &td = (*iter)[col_data];
+    td.apply_to_cell (cell);
+}
+
 Guikachu::Resource * ResourceTree::get_selected ()
 {
     Glib::RefPtr<Gtk::TreeSelection> tree_selection = get_selection ();
@@ -104,7 +114,8 @@ Guikachu::Resource * ResourceTree::get_selected ()
     if (!iter)
         return 0;
 
-    return (*iter)[col_res];
+    const TreeData &td = (*iter)[col_data];
+    return td.get_resource ();
 }
 
 void ResourceTree::set_manager (ResourceManager *manager_)
@@ -118,106 +129,95 @@ void ResourceTree::set_manager (ResourceManager *manager_)
     subtrees.clear ();
 
     root_tree = *(treestore->append ());
-    root_tree[col_res] = 0;
+    root_tree[col_data] = manager->get_application ();
 
     manager->get_application ()->changed.connect (
-	SigC::slot (*this, &ResourceTree::app_changed_cb));
-    app_changed_cb ();
+	sigc::mem_fun (*this, &ResourceTree::app_changed_cb));
+
+    create_tree_for_type (Resources::RESOURCE_FORM);
+    create_tree_for_type (Resources::RESOURCE_MENU);
+    create_tree_for_type (Resources::RESOURCE_BITMAP);
+    create_tree_for_type (Resources::RESOURCE_STRING);
+    create_tree_for_type (Resources::RESOURCE_BLOB);
     
-    create_tree_for_type (Resources::RESOURCE_FORM,         _("Forms"));
-    create_tree_for_type (Resources::RESOURCE_DIALOG,       _("Dialogs"));
-    create_tree_for_type (Resources::RESOURCE_MENU,         _("Menus"));
-    create_tree_for_type (Resources::RESOURCE_BITMAP,       _("Bitmaps"));
-    create_tree_for_type (Resources::RESOURCE_BITMAPFAMILY, _("Bitmap groups"));
-    create_tree_for_type (Resources::RESOURCE_STRING,       _("Strings"));
-    create_tree_for_type (Resources::RESOURCE_STRINGLIST,   _("String lists"));
-    create_tree_for_type (Resources::RESOURCE_BLOB,         _("Blobs"));
-
     manager->resource_created.connect (
-	SigC::slot (*this, &ResourceTree::resource_created_cb));
+	sigc::mem_fun (*this, &ResourceTree::resource_created_cb));
     manager->resource_removed.connect (
-	SigC::slot (*this, &ResourceTree::resource_removed_cb));
-
+	sigc::mem_fun (*this, &ResourceTree::resource_removed_cb));
+    
     // Create tree items for existing resources
     const std::set<Resource*> resources = manager->get_resources ();
     std::for_each (resources.begin (), resources.end (),
-		   SigC::slot (*this, &ResourceTree::resource_created_cb));
+		   sigc::mem_fun (*this, &ResourceTree::resource_created_cb));
 
     expand_all ();
 }
 
-void ResourceTree::create_tree_for_type (Resources::Type      type,
-					 const Glib::ustring &category_name)
+void ResourceTree::create_tree_for_type (Resources::Type type)
 {
-    g_return_if_fail (subtrees.find (type) == subtrees.end ());
-    
+    if (subtrees.find (type) != subtrees.end ())
+        return;
+
     Gtk::TreeRow row = *(treestore->append (root_tree.children ()));
-    row[col_label] = category_name;
-    row[col_res] = 0;
+    row[col_data] = type;
 
     subtrees[type] = row;
+
+    switch (type)
+    {
+    case Resources::RESOURCE_FORM:
+    case Resources::RESOURCE_DIALOG:
+        subtrees[Resources::RESOURCE_FORM] = subtrees[Resources::RESOURCE_DIALOG] = row;
+        break;
+
+    case Resources::RESOURCE_STRING:
+    case Resources::RESOURCE_STRINGLIST:
+        subtrees[Resources::RESOURCE_STRING] = subtrees[Resources::RESOURCE_STRINGLIST] = row;
+        break;
+
+    case Resources::RESOURCE_BITMAP:
+    case Resources::RESOURCE_BITMAPFAMILY:
+        subtrees[Resources::RESOURCE_BITMAP] = subtrees[Resources::RESOURCE_BITMAPFAMILY] = row;
+        break;
+
+    default:
+        break;
+    }
 }
 
 void ResourceTree::app_changed_cb ()
 {
-    std::string app_id = manager->get_application ()->iconname;
-    if (app_id == "")
-	app_id = _("Application");
-    
-    root_tree[col_label] = app_id;
+    treestore->row_changed (treestore->get_path (root_tree), root_tree);
 }
 
-namespace {
-    struct ResourceFinder: public std::unary_function<Gtk::TreeModel::iterator, bool> 
-    {
-	typedef Guikachu::Resource *             target_t;
-	typedef Gtk::TreeModelColumn<target_t> & col_t;
-	
-	target_t target;
-	col_t    col;
-	
-	ResourceFinder (target_t target_, col_t col_) :
-	    target (target_), col (col_) {};
-	
-	bool operator() (const Gtk::TreeRow &row) {
-	    return row[col] == target;
-	}
-    };
-} // anonymous namespace
-
 void ResourceTree::resource_removed_cb (Resource *res)
 {
-    Gtk::TreeModel::Row &subtree_row = subtrees[res->get_type ()];
-    Gtk::TreeModel::Children rows = subtree_row->children ();
-    Gtk::TreeModel::iterator begin = rows.begin ();
-    Gtk::TreeModel::iterator end = rows.end ();
+    row_map_t::iterator row_found = row_map.find (res);
+    g_return_if_fail (row_found != row_map.end ());
 
-    // This is an O(n) lookup, where n is the number of resources
-    Gtk::TreeModel::iterator res_found = std::find_if (begin, end, ResourceFinder (res, col_res));
-    g_return_if_fail (res_found != end);
-
-    treestore->erase (res_found);
+    treestore->erase (row_found->second);
+    row_map.erase (row_found);
 }
 
 void ResourceTree::resource_created_cb (Resource *res)
 {
+    create_tree_for_type (res->get_type ());
     Gtk::TreeRow &subtree_row = subtrees[res->get_type ()];
 
     Gtk::TreeRow row = *(treestore->append (subtree_row.children ()));
-    row[col_label] = Glib::ustring (res->id);
-    row[col_res] = res;
+    row[col_data] = res;
 
-    expand_row (treestore->get_path (subtree_row), true);
+    row_map[res] = row;
     
-    res->changed.connect (SigC::bind (
-	SigC::slot (*this, &ResourceTree::resource_changed_cb), row));
+    res->changed.connect (sigc::bind (
+	sigc::mem_fun (*this, &ResourceTree::resource_changed_cb), row));
+    
+    expand_row (treestore->get_path (subtree_row), true);
 }
 
 void ResourceTree::resource_changed_cb (Gtk::TreeRow row)
 {
-    Resource *res = row[col_res];
-    
-    row[col_label] = Glib::ustring (res->id);
+    treestore->row_changed (treestore->get_path (root_tree), root_tree);
 }
 
 void ResourceTree::show_app_win ()
@@ -245,12 +245,11 @@ void ResourceTree::row_activated_cb (const Gtk::TreeModel::Path &path,
         show_app_win ();
 	return;
     }
-    
-    if ((*iter)[col_res])
-    {
-	Resource *res = (*iter)[col_res];
+
+    const TreeData &td = (*iter)[col_data];
+    Resource *res = td.get_resource ();
+    if (res)
         show_res_win (res);
-    }
 }
 
 void ResourceTree::button_press_cb (GdkEventButton *e)
@@ -267,10 +266,12 @@ void ResourceTree::button_press_cb (GdkEventButton *e)
     if (get_path_at_pos (e->x, e->y, path, column, cell_x, cell_y))
     {
 	Gtk::TreeModel::iterator iter = treestore->get_iter (path);
+        const TreeData &td = (*iter)[col_data];
+    
         if (iter == treestore->children ().begin ())
             popup_app_menu (e->button, e->time);
         else
-            resource = (*iter)[col_res];
+            resource = td.get_resource ();
     }
     
     if (resource)
@@ -283,7 +284,8 @@ void ResourceTree::key_press_cb (GdkEventKey *e)
     if (!iter)
         return;
 
-    Resource *res = (*iter)[col_res];
+    const TreeData &td = (*iter)[col_data];
+    Resource *res = td.get_resource ();
     if (!res && iter != treestore->children ().begin ())
         return;
 
@@ -328,7 +330,7 @@ void ResourceTree::popup_app_menu (guint button, guint32 time)
     popup_menu_list.push_back (
 	Gnome::UI::Items::Item (Gnome::UI::Items::Icon (Gtk::Stock::PROPERTIES),
 				_("_Edit"),
-				SigC::slot (*this, &ResourceTree::show_app_win)));
+				sigc::mem_fun (*this, &ResourceTree::show_app_win)));
 
     Gnome::UI::Items::fill (*popup_menu, popup_menu_list,
 			    popup_menu->get_accel_group ());
@@ -356,14 +358,14 @@ void ResourceTree::popup_res_menu (guint button, guint32 time, Resource *res)
     Gnome::UI::Items::Info popup_menu_list[] = {
 	Gnome::UI::Items::Item (Gnome::UI::Items::Icon (Gtk::Stock::PROPERTIES),
 				_("_Edit"),
-				SigC::bind (SigC::slot (*this, &ResourceTree::show_res_win), res)),
+				sigc::bind (sigc::mem_fun (*this, &ResourceTree::show_res_win), res)),
 	Gnome::UI::Items::Separator (),
-	Gnome::UI::MenuItems::Cut   (SigC::bind (SigC::slot (*this, &ResourceTree::res_cut_cb), res)),
-	Gnome::UI::MenuItems::Copy  (SigC::bind (SigC::slot (*this, &ResourceTree::res_copy_cb), res)),
+	Gnome::UI::MenuItems::Cut   (sigc::bind (sigc::mem_fun (*this, &ResourceTree::res_cut_cb), res)),
+	Gnome::UI::MenuItems::Copy  (sigc::bind (sigc::mem_fun (*this, &ResourceTree::res_copy_cb), res)),
 	Gnome::UI::Items::Separator (),
 	Gnome::UI::Items::Item (Gnome::UI::Items::Icon (Gtk::Stock::DELETE),
 				_("_Remove"),
-				SigC::bind (SigC::slot (*this, &ResourceTree::res_remove_cb), res)),
+				sigc::bind (sigc::mem_fun (*this, &ResourceTree::res_remove_cb), res)),
     };
 
     Gnome::UI::Items::fill (*popup_menu, popup_menu_list,
