@@ -1,4 +1,4 @@
-//$Id: resource.h,v 1.36 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: resource.h,v 1.37 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -51,7 +51,7 @@ namespace Guikachu
 
 namespace Guikachu
 {
-    class Resource: public SigC::Object
+    class Resource: public sigc::trackable
     {
     protected:
 	Resource (ResourceManager   *manager,
@@ -73,7 +73,7 @@ namespace Guikachu
 	virtual void apply_visitor (ResourceVisitor &visitor) = 0;
 	
 	// Notification
-	SigC::Signal0<void> deleted;
+	sigc::signal0<void> deleted;
 	QueuedSignal        changed;
 	
 	// Common properties
