@@ -1,4 +1,4 @@
-//$Id: session.cc,v 1.23 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: session.cc,v 1.26 2004/07/12 22:07:57 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -25,7 +25,7 @@
 #include <libgnomeuimm/init.h>
 #include <foocanvasmm/init.h>
 
-#include <sigc++/bind_return.h>
+#include <sigc++/adaptors/bind_return.h>
 #include "queued-signal.h"
 
 #include "resource-manager.h"
@@ -42,9 +42,9 @@ namespace {
     void io_load_error (const Glib::ustring &uri, const Glib::ustring &error_msg);
     void io_save_error (const Glib::ustring &uri, const Glib::ustring &error_msg);
 
-    void gtk_queuer (SigC::Slot0<void> slot)
+    void gtk_queuer (sigc::slot<void> slot)
     {
-        Glib::signal_idle ().connect (SigC::bind_return (slot, false), Glib::PRIORITY_DEFAULT_IDLE);
+        Glib::signal_idle ().connect (sigc::bind_return (slot, false), Glib::PRIORITY_DEFAULT_IDLE);
     }   
 } // anonymous namespace
 
@@ -70,8 +70,8 @@ Main::Main (int argc, char **argv):
     Gnome::UI::Client* session_client = Gnome::UI::Client::master_client ();
     if (session_client)
     {
-	session_client->signal_die ().connect (SigC::slot(*this, &Main::session_die_cb));
-	session_client->signal_save_yourself ().connect (SigC::slot(*this, &Main::session_save_cb));
+	session_client->signal_die ().connect (sigc::mem_fun(*this, &Main::session_die_cb));
+	session_client->signal_save_yourself ().connect (sigc::mem_fun (*this, &Main::session_save_cb));
     }
 
     // Store command-line arguments
@@ -91,11 +91,11 @@ Main::Main (int argc, char **argv):
     mainwin = new GUI::MainWin;
     mainwin->set_manager (doc);
 
-    // Load document (last filename) from command line
+    // Load document (last uri) from command line
     if (cmd_arguments.size ())
     {
 	std::string uri = IO::create_canonical_uri (*cmd_arguments.rbegin ());
-	load_doc (uri, "application/x-guikachu");
+	load_doc (uri);
     }
 }
 
@@ -138,25 +138,25 @@ void io_save_error (const Glib::ustring &uri, const Glib::ustring &error_msg)
 
 void Main::set_doc (ResourceManager *new_doc)
 {
+    mainwin->set_manager (new_doc);
+    
     delete doc;
     doc = new_doc;
-
-    mainwin->set_manager (doc);
 }
 
 void Main::new_doc ()
 {
+    ResourceManager *new_doc = new ResourceManager;
+    mainwin->set_manager (new_doc);
+
     delete doc;
-    doc = new ResourceManager;
+    doc = new_doc;
     
-    mainwin->set_manager  (doc);
-    mainwin->set_filename ("");
+    mainwin->set_uri ("");
 }
 
-void Main::save_doc (const Glib::ustring &filename)
+void Main::save_doc (const Glib::ustring &uri)
 {
-    std::string uri = IO::create_canonical_uri (filename);
-    
     IO::Saver    *saver = new IO::XMLSaver;
     IO::IOResult  res = saver->save (doc, uri);
     delete saver;
@@ -164,20 +164,18 @@ void Main::save_doc (const Glib::ustring &filename)
     if (res == GNOME_VFS_OK)
     {
 	doc->clear_dirty ();
-	set_filename (uri, "application/x-guikachu");
+	set_uri (uri, "application/x-guikachu");
     } else {
 	io_save_error (uri, gnome_vfs_result_to_string (res));
     }
 }
 
-void Main::load_doc (const Glib::ustring &filename,
-                     const std::string   &mime_type)
+void Main::load_doc (const Glib::ustring &uri)
 {
-    std::string uri = IO::create_canonical_uri (filename);
-    
     ResourceManager *new_doc = new ResourceManager;
 
-    IO::Loader   *loader = IO::IOFactory::instance ()->create_loader (mime_type);
+    std::string mime_type = IO::get_mime_type (uri);
+    IO::Loader *loader = IO::IOFactory::instance ()->create_loader (mime_type);
     if (!loader)
     {
 	char *error_msg = g_strdup_printf (_("File format %s unknown"), mime_type.c_str ());
@@ -194,7 +192,7 @@ void Main::load_doc (const Glib::ustring &filename,
     if (res == GNOME_VFS_OK)
     {
 	set_doc (new_doc);
-	set_filename (uri, mime_type);
+	set_uri (uri, mime_type);
     } else {
 	io_load_error (uri, gnome_vfs_result_to_string (res));
 	delete new_doc;
@@ -224,29 +222,24 @@ void Guikachu::Main::save_open_file ()
     {
 	std::vector<std::string> argv;
 	argv.push_back (cmd_self);
-	argv.push_back (last_filename);
+	argv.push_back (last_uri);
 	
 	session_client->set_clone_command (argv);
 	session_client->set_restart_command (argv);
     }
 }
 
-void Guikachu::Main::set_filename (const Glib::ustring &filename,
-                                   const std::string   &mime_type)
+void Guikachu::Main::set_uri (const Glib::ustring &uri,
+                              const std::string   &mime_type)
 {
-    // FIXME: make sure this is UTF8-safe
-    
-    Glib::ustring canonical_filename = filename;
-    
-    if (filename != "")
-	Preferences::Interface::add_recent_file (
-	    Preferences::Interface::RecentFileEntry (filename, mime_type));
+    if (uri != "")
+	Preferences::Interface::add_recent_file (uri);
 
     if (mime_type == "application/x-guikachu")
     {
-	last_filename = filename;
-	mainwin->set_filename (filename);
+	last_uri = uri;
+	mainwin->set_uri (uri);
     } else {
-	mainwin->set_filename ("");
+	mainwin->set_uri ("");
     }
 }
