@@ -1,4 +1,4 @@
-//$Id: session.h,v 1.12 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: session.h,v 1.13 2004/07/12 22:07:57 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -42,7 +42,7 @@ namespace Guikachu
 	poptContext               ctx;
 	std::string               cmd_self;
 	std::vector<std::string>  cmd_arguments;
-	Glib::ustring             last_filename;
+	Glib::ustring             last_uri;
 
 	ResourceManager          *doc;
 	GUI::MainWin             *mainwin;
@@ -53,16 +53,16 @@ namespace Guikachu
 	static inline bool  initialized () { return instance_ != 0; };
 	~Main ();
 
-        void load_doc (const Glib::ustring &filename, const std::string &mime_type);
-	void save_doc (const Glib::ustring &filename);
+        void load_doc (const Glib::ustring &uri);
+	void save_doc (const Glib::ustring &uri);
 	void new_doc  ();
 
     protected:
 	void run_impl ();
 	
     private:
-	void set_doc      (ResourceManager   *doc);
-        void set_filename (const Glib::ustring &filename, const std::string &mime_type);
+	void set_doc (ResourceManager   *doc);
+        void set_uri (const Glib::ustring &uri, const std::string &mime_type);
 	
 	bool session_save_cb (int                      phase,
 			      Gnome::UI::SaveStyle     save_style,
