@@ -1,4 +1,4 @@
-//$Id: storage.h,v 1.14 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: storage.h,v 1.15 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -49,7 +49,7 @@ namespace Guikachu
 	void        set_root    (StorageNode &root);
 	StorageNode create_root (const std::string &name);
 
-	SigC::Signal0<void> encoding_notify;
+	sigc::signal0<void> encoding_notify;
     };
     
 }; // namespace Guikachu
