@@ -1,4 +1,4 @@
-//$Id: stringlist-win.h,v 1.6 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: stringlist-win.h,v 1.7 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -29,7 +29,7 @@ namespace Guikachu
     namespace GUI
     {
 	class StringListWindow: public ResourceWindow,
-				public SigC::Object
+				public sigc::trackable
 	{
 	    Resources::StringList *res;
 	    Gtk::Window            window;
