@@ -1,4 +1,4 @@
-//$Id: ui-gui.cc,v 1.5 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: ui-gui.cc,v 1.7 2004/07/12 21:49:04 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -58,7 +58,7 @@ void UI::show_about ()
     
     static Gnome::UI::About *about = new Gnome::UI::About (
 	"Guikachu", VERSION,
-	"(C) 2001-2003 Gerg\xC5\x91 \xC3\x89rdi",
+	"(C) 2001-2004 Gerg\xC5\x91 \xC3\x89rdi",
 	authors,
 	documenters,
 	_("PalmOS resource file editor"),
@@ -72,7 +72,7 @@ void UI::show_error (const Glib::ustring &full_message,
 {
     if (Guikachu::Main::initialized ())
     {
-	Gtk::MessageDialog dialog (full_message, Gtk::MESSAGE_ERROR,
+	Gtk::MessageDialog dialog (full_message, true, Gtk::MESSAGE_ERROR,
                                    Gtk::BUTTONS_OK, true);
         dialog.run ();
     } else {
@@ -86,7 +86,7 @@ void UI::show_warning (const Glib::ustring &full_message,
 {
     if (Guikachu::Main::initialized ())
     {
-	Gtk::MessageDialog dialog (full_message, Gtk::MESSAGE_WARNING,
+	Gtk::MessageDialog dialog (full_message, true, Gtk::MESSAGE_WARNING,
                                    Gtk::BUTTONS_OK, true);
         dialog.run ();
     } else {
