@@ -1,4 +1,4 @@
-//$Id: font-combo.cc,v 1.6 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: font-combo.cc,v 1.7 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -22,6 +22,7 @@
 #include <libgnome/libgnome.h>
 
 #include <gtkmm/menu.h>
+#include <sigc++/adaptors/bind.h>
 
 using namespace Guikachu::GUI::PropertyEditors;
 
@@ -37,7 +38,7 @@ FontCombo::FontCombo (property_t   &property_,
 #define FONT_ITEM(s, num)							\
 	menu_items->items ().push_back (					\
 	    Gtk::Menu_Helpers::MenuElem (					\
-		s, SigC::bind (SigC::slot (*this, &FontCombo::menu_cb), num)));
+		s, sigc::bind (sigc::mem_fun (*this, &FontCombo::menu_cb), num)));
 
     FONT_ITEM (_("Regular"), 0);
     FONT_ITEM (_("Bold"), 1);
@@ -53,7 +54,7 @@ FontCombo::FontCombo (property_t   &property_,
     menu_items->show_all ();
     set_menu (*manage (menu_items));
     
-    property.changed.connect (SigC::slot (*this, &FontCombo::update));
+    property.changed.connect (sigc::mem_fun (*this, &FontCombo::update));
     update ();
 }
 
