@@ -1,6 +1,6 @@
-//$Id: property-editor.cc,v 1.4 2003/06/30 14:08:00 cactus Exp $ -*- c++ -*-
+//$Id: property-editor.cc,v 1.6 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -25,11 +25,11 @@ PropertyEditor::PropertyEditor (Gtk::Widget *underline_widget_):
 {
 }
 
-void PropertyEditor::install_underline (Gtk::AccelGroup &accel_group,
-					guint            accel_key)
+void PropertyEditor::install_underline (Glib::RefPtr<Gtk::AccelGroup> &accel_group,
+					unsigned int                   accel_key)
 {
     if (underline_widget)
 	underline_widget->add_accelerator ("grab_focus",
 					   accel_group, accel_key,
-					   GDK_MOD1_MASK, GTK_ACCEL_VISIBLE);
+					   Gdk::MOD1_MASK, Gtk::ACCEL_VISIBLE);
 }
