@@ -1,6 +1,6 @@
-//$Id: property-editor.h,v 1.4 2003/06/30 14:08:00 cactus Exp $ -*- c++ -*-
+//$Id: property-editor.h,v 1.6 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -19,7 +19,7 @@
 #ifndef GUIKACHU_WIDGETS_PROPERTY_EDITOR_H
 #define GUIKACHU_WIDGETS_PROPERTY_EDITOR_H
 
-#include <gtk--/widget.h>
+#include <gtkmm/widget.h>
 
 namespace Guikachu
 {
@@ -42,8 +42,8 @@ namespace Guikachu
 	public:
 	    virtual LabelAlignment get_label_alignment () { return LABEL_ALIGN_CENTER; };
 	    virtual bool           get_resizeable ()      { return false; };
-	    virtual void           install_underline (Gtk::AccelGroup &accel_group,
-						      guint            accel_key);
+	    virtual void           install_underline (Glib::RefPtr<Gtk::AccelGroup> &accel_group,
+						      unsigned int                   accel_key);
 	};
     }
 }
