@@ -1,4 +1,4 @@
-//$Id: propertytable.cc,v 1.23 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: propertytable.cc,v 1.24 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -39,8 +39,8 @@ PropertyTable::PropertyTable ():
     set_row_spacings (5);
     set_col_spacings (5);
 
-    signal_parent_changed ().connect (SigC::slot (*this, &PropertyTable::parent_changed_cb));
-    signal_map ().connect (SigC::slot (*this, &PropertyTable::map_cb));
+    signal_parent_changed ().connect (sigc::mem_fun (*this, &PropertyTable::parent_changed_cb));
+    signal_map ().connect (sigc::mem_fun (*this, &PropertyTable::map_cb));
 }
 
 Gtk::Widget *PropertyTable::create_label (const Glib::ustring &label,
