@@ -1,4 +1,4 @@
-//$Id: resource-combo.cc,v 1.18 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: resource-combo.cc,v 1.19 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -73,17 +73,17 @@ void ResourceCombo::create_widgets ()
 	 i != resource_set.end (); i++)
 	add_resource ((*i));
 
-    button_edit.signal_clicked ().connect (slot (*this, &ResourceCombo::edit_cb));
+    button_edit.signal_clicked ().connect (sigc::mem_fun (*this, &ResourceCombo::edit_cb));
     
-    manager->resource_created.connect (slot (*this, &ResourceCombo::add_resource));
-    manager->resource_removed.connect (slot (*this, &ResourceCombo::remove_resource));
-    combo.get_entry ()->signal_changed ().connect (slot (*this, &ResourceCombo::entry_cb));
+    manager->resource_created.connect (sigc::mem_fun (*this, &ResourceCombo::add_resource));
+    manager->resource_removed.connect (sigc::mem_fun (*this, &ResourceCombo::remove_resource));
+    combo.get_entry ()->signal_changed ().connect (sigc::mem_fun (*this, &ResourceCombo::entry_cb));
     
     pack_start (combo);
     pack_start (button_edit);
     underline_widget = &combo;
     
-    property.changed.connect (slot (*this, &ResourceCombo::update));
+    property.changed.connect (sigc::mem_fun (*this, &ResourceCombo::update));
     update ();
 }
 
@@ -102,8 +102,8 @@ void ResourceCombo::add_resource (Resource *res)
     
     combo.get_entry ()->set_text (current);
 
-    res->changed.connect (SigC::bind (
-	SigC::slot (*this, &ResourceCombo::resource_changed_cb),
+    res->changed.connect (sigc::bind (
+	sigc::mem_fun (*this, &ResourceCombo::resource_changed_cb),
 	res));
 	
     update_block = false;
