@@ -1,6 +1,6 @@
-//$Id: resource-combo.h,v 1.13 2004/01/18 10:55:39 cactus Exp $ -*- c++ -*-
+//$Id: resource-combo.h,v 1.15 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -27,9 +27,9 @@ namespace Guikachu
     }
 }
 
-#include <gtk--/box.h>
-#include <gtk--/combo.h>
-#include <gtk--/button.h>
+#include <gtkmm/box.h>
+#include <gtkmm/combo.h>
+#include <gtkmm/button.h>
 #include "resource.h"
 #include "resource-ref.h"
 #include "property-editor.h"
