@@ -1,4 +1,4 @@
-//$Id: target-combo.cc,v 1.10 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: target-combo.cc,v 1.11 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -63,18 +63,18 @@ TargetCombo::TargetCombo (ResourceManager *manager_):
 	 i != targets.end (); ++i, ++current_index)
     {
 	target_menu->items ().push_back (Gtk::Menu_Helpers::MenuElem (
-	    i->second, bind (slot (*this, &TargetCombo::target_stock_cb), i->first)));
+            i->second, sigc::bind (sigc::mem_fun (*this, &TargetCombo::target_stock_cb), i->first)));
 	
 	stock_target_to_menuitem[i->first] = current_index;
     }
     
     target_menu->items ().push_back (Gtk::Menu_Helpers::MenuElem (
-        _("Custom machine"), slot (*this, &TargetCombo::target_custom_cb)));
+        _("Custom machine"), sigc::mem_fun (*this, &TargetCombo::target_custom_cb)));
     num_targets = current_index;
     
     set_menu (*manage (target_menu));
 
-    target->changed.connect (SigC::slot (*this, &TargetCombo::update));
+    target->changed.connect (sigc::mem_fun (*this, &TargetCombo::update));
     update ();
 }
 
