@@ -1,4 +1,4 @@
-//$Id: target-combo.h,v 1.10 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: target-combo.h,v 1.11 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -41,8 +41,8 @@ namespace Guikachu
 	    public:
 		TargetCombo (ResourceManager *manager);
 
-		SigC::Signal0<void> custom_selected;
-		SigC::Signal0<void> stock_selected;
+		sigc::signal0<void> custom_selected;
+		sigc::signal0<void> stock_selected;
 		
 	    private:
 		void update ();
