@@ -1,4 +1,4 @@
-//$Id: text.cc,v 1.14 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: text.cc,v 1.15 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -33,12 +33,12 @@ TextArea::TextArea (property_t   &property_,
     text_widget.set_wrap_mode (Gtk::WRAP_WORD);
     text_widget.set_editable (true);
     
-    text_widget.get_buffer ()->signal_changed ().connect (SigC::slot (*this, &TextArea::changed_cb));
+    text_widget.get_buffer ()->signal_changed ().connect (sigc::mem_fun (*this, &TextArea::changed_cb));
 
     set_policy (Gtk::POLICY_NEVER, Gtk::POLICY_ALWAYS);
     add (text_widget);
     
-    property.changed.connect (slot (*this, &TextArea::update));
+    property.changed.connect (sigc::mem_fun (*this, &TextArea::update));
     update ();
 }
 
